@@ -2,8 +2,11 @@
 
 #include "os_gl.h"
 
-// Generic Error Handing
-bool glCheckOkay();
+#include <string_view>
+
+struct PyMOLGlobals;
+
+bool CheckGLErrorOK(PyMOLGlobals* G, std::string_view errString);
 
 void GLAPIENTRY gl_debug_proc(GLenum, GLenum, GLuint, GLenum, GLsizei, const GLchar *, const void *);
 // userParam is qualified as const in OpenGL 4.4 spec but non-const in OpenGL 4.3 spec
