@@ -15,13 +15,13 @@ I* Additional authors of this source file include:
 -*
 Z* -------------------------------------------------------------------
 */
+
+#include <random>
+
 #include"os_python.h"
 #include"os_predef.h"
 #include"os_std.h"
 
-#include"OVRandom.h"
-#include"OVContext.h"
-
 #include"Isosurf.h"
 #include"MemoryDebug.h"
 #include"Err.h"
@@ -44,11 +44,13 @@ Z* -------------------------------------------------------------------
 
 #define I4(field,P1,P2,P3,P4) ((field)->get<int>(P1,P2,P3,P4))
 
-typedef struct PointType {
+namespace {
+struct PointType {
   float Point[3];
   int NLink;
   struct PointType* Link[4];
-} PointType;
+};
+}
 
 #define EdgePtPtr(field,P2,P3,P4,P5) ((field)->ptr(P2,P3,P4,P5))
 
@@ -97,14 +99,14 @@ static void _IsosurfFree(CIsosurf * I)
 void IsosurfFree(PyMOLGlobals * G)
 {
   _IsosurfFree(G->Isosurf);
-  G->Isosurf = NULL;
+  G->Isosurf = nullptr;
 }
 
 
 /*===========================================================================*/
 PyObject *IsosurfAsPyList(PyMOLGlobals * G, Isofield * field)
 {
-  PyObject *result = NULL;
+  PyObject *result = nullptr;
 
   result = PyList_New(4);
 
@@ -114,7 +116,7 @@ PyObject *IsosurfAsPyList(PyMOLGlobals * G, Isofield * field)
   if(field->save_points)
     PyList_SetItem(result, 3, FieldAsPyList(G, field->points.get()));
   else
-    PyList_SetItem(result, 3, PConvAutoNone(NULL));
+    PyList_SetItem(result, 3, PConvAutoNone(nullptr));
   return (PConvAutoNone(result));
 }
 
@@ -139,9 +141,9 @@ Isofield *IsosurfNewFromPyList(PyMOLGlobals * G, PyObject * list)
   int dim4[4];
   int a;
 
-  Isofield *result = NULL;
+  Isofield *result = nullptr;
   if(ok)
-    ok = (list != NULL);
+    ok = (list != nullptr);
   if(ok)
     ok = PyList_Check(list);
   /* TO ENABLE BACKWARDS COMPATIBILITY...
@@ -395,10 +397,10 @@ static CIsosurf *IsosurfNew(PyMOLGlobals * G)
   int c;
   CIsosurf *I = pymol::calloc<CIsosurf>(1);
   I->G = G;
-  I->VertexCodes = NULL;
-  I->ActiveEdges = NULL;
-  I->Point = NULL;
-  I->Line = NULL;
+  I->VertexCodes = nullptr;
+  I->ActiveEdges = nullptr;
+  I->Point = nullptr;
+  I->Line = nullptr;
   I->Skip = 0;
   for(c = 0; c < 256; c++)
     I->Code[c] = -1;
@@ -1040,13 +1042,13 @@ static int IsosurfGradients(PyMOLGlobals * G, CSetting * set1, CSetting * set2,
     CField *points = field->points.get();
 
     /* flags marking excluded regions to avoid (currently wasteful) */
-    int *flag = NULL;
+    int *flag = nullptr;
 
     /* variable length array for recording segment paths */
     int *active_cell = VLAlloc(int, 1000);
 
     /* ordered list of coordinates for processing */
-    int *order = NULL;
+    int *order = nullptr;
 
     int range_size;             /* total points in region being drawn */
     int range_dim[3];           /* dimension of drawn region */
@@ -1095,7 +1097,8 @@ static int IsosurfGradients(PyMOLGlobals * G, CSetting * set1, CSetting * set2,
         /* generate randomized list of cell coordinates */
 
         /* always use same seed for same volume */
-        OVRandom *my_rand = OVRandom_NewBySeed(G->Context->heap, range_size);
+        std::mt19937 mt(range_size);
+        std::uniform_real_distribution<float> dist{};
         {
           /* fill */
           int i, j, k, *p = order;
@@ -1114,8 +1117,8 @@ static int IsosurfGradients(PyMOLGlobals * G, CSetting * set1, CSetting * set2,
           /* shuffle */
           int a;
           for(a = 0; a < range_size; a++) {
-            int *p = order + 3 * (int) (range_size * OVRandom_Get_float64_exc1(my_rand));
-            int *q = order + 3 * (int) (range_size * OVRandom_Get_float64_exc1(my_rand));
+            int *p = order + 3 * (int) (range_size * dist(mt));
+            int *q = order + 3 * (int) (range_size * dist(mt));
             int t0 = p[0], t1 = p[1], t2 = p[2];
             p[0] = q[0];
             p[1] = q[1];
@@ -1125,7 +1128,6 @@ static int IsosurfGradients(PyMOLGlobals * G, CSetting * set1, CSetting * set2,
             q[2] = t2;
           }
         }
-        OVRandom_Del(my_rand);
       }
 
       {
@@ -1149,7 +1151,7 @@ static int IsosurfGradients(PyMOLGlobals * G, CSetting * set1, CSetting * set2,
           for(pass = 0; pass < 2; pass++) {     /* one pass down the gradient, one up */
 
             int have_prev = false;      /* flag & storage for previous gradient & locus */
-            int *prev_locus = NULL;
+            int *prev_locus = nullptr;
 
             int locus[3];       /* what cell are we in? */
             float fract[3] = { 0.0F, 0.0F, 0.0F };      /* where in the cell are we? */
@@ -1214,7 +1216,7 @@ static int IsosurfGradients(PyMOLGlobals * G, CSetting * set1, CSetting * set2,
               if((!have_prev) || (have_prev && ((locus[0] != prev_locus[0]) ||
                                                 (locus[1] != prev_locus[1]) ||
                                                 (locus[2] != prev_locus[2])))) {
-                /* above: prev_locus may be NULL, so relying upon shortcut logic eval */
+                /* above: prev_locus may be nullptr, so relying upon shortcut logic eval */
 
                 /* stop if we hit a flagged cell (flag always in lower corner) */
 
@@ -1674,7 +1676,7 @@ static int IsosurfDrawLines(CIsosurf * II)
 #ifdef Trace
                 LCount++;
 #endif
-                Cur = NULL;
+                Cur = nullptr;
                 if(I->NLine != (*I->Num)[I->NSeg]) {       /* any new lines? */
                   I->Num->check(I->NSeg + 1);
                   (*I->Num)[I->NSeg] = I->NLine - (*I->Num)[I->NSeg];
@@ -1736,8 +1738,8 @@ static int IsosurfFindLines(CIsosurf * II)
               printf("IsosurfFindLines: bad index: %i \n", index);
 #endif
             while(cod > 0) {
-              p1 = NULL;
-              p2 = NULL;
+              p1 = nullptr;
+              p2 = nullptr;
               switch (cod) {
               case 40:
               case 32:
@@ -1773,8 +1775,8 @@ static int IsosurfFindLines(CIsosurf * II)
                 break;
               default:
                 cod = 0;
-                p1 = NULL;
-                p2 = NULL;
+                p1 = nullptr;
+                p2 = nullptr;
                 break;
               }
               if(p1 && p2) {
@@ -1836,8 +1838,8 @@ static int IsosurfFindLines(CIsosurf * II)
                 break;
               default:
                 cod = 0;
-                p1 = NULL;
-                p2 = NULL;
+                p1 = nullptr;
+                p2 = nullptr;
                 break;
               }
               if(p1 && p2) {
@@ -1899,8 +1901,8 @@ static int IsosurfFindLines(CIsosurf * II)
                 break;
               default:
                 cod = 0;
-                p1 = NULL;
-                p2 = NULL;
+                p1 = nullptr;
+                p2 = nullptr;
                 break;
               }
               if(p1 && p2) {
