@@ -46,18 +46,6 @@ typedef struct VLARec {
 #define VLAInsert(ptr,type,index,count) {ptr=(type*)VLAInsertRaw(ptr,index,count);}
 #define VLADelete(ptr,type,index,count) {ptr=(type*)VLADeleteRaw(ptr,index,count);}
 
-#if defined(_PYMOL_IOS) && !defined(_WEBGL)
-#include "MemoryUsage.h"
-extern "C" void fireMemoryWarning();
-#define PYMOL_IOS_MEMORY_CHECK                                                 \
-  if (pymol::memory_available() < sizeof(T) * num) {                           \
-    fireMemoryWarning();                                                       \
-    return nullptr;                                                            \
-  }
-#else
-#define PYMOL_IOS_MEMORY_CHECK
-#endif
-
 namespace pymol
 {
 using ::free;
@@ -82,9 +70,9 @@ template <typename T> T* realloc(T* ptr, size_t num)
 }
 } // namespace pymol
 
-#define FreeP(ptr) {if(ptr) {mfree(ptr);ptr=NULL;}}
-#define DeleteP(ptr) {if(ptr) {delete ptr;ptr=NULL;}}
-#define DeleteAP(ptr) {if(ptr) {delete[] ptr;ptr=NULL;}}
+#define FreeP(ptr) {if(ptr) {mfree(ptr);ptr=nullptr;}}
+#define DeleteP(ptr) {if(ptr) {delete ptr;ptr=nullptr;}}
+#define DeleteAP(ptr) {if(ptr) {delete[] ptr;ptr=nullptr;}}
 
 void *VLAExpand(void *ptr, ov_size rec);        /* NOTE: rec is index (total-1) */
 void *MemoryReallocForSure(void *ptr, size_t newSize);
