@@ -5,6 +5,8 @@
 #ifdef PURE_OPENGL_ES_2
 # define GLEW_EXT_gpu_shader4 false
 # define GLEW_EXT_geometry_shader4 false
+# define GLEW_ARB_tessellation_shader false
+# define GLEW_ARB_gpu_shader5 false
 # ifdef _WEBGL
 #  include <emscripten/val.h>
 #  define GLEW_EXT_draw_buffers2 !emscripten::val::module_property("ONEBUFFER").as<bool>()
