@@ -33,6 +33,12 @@
 #endif
 
 #include "os_gl_glut.h"
+#include "Spatial.h"
+
+struct GLFramebufferConfig {
+  std::uint32_t framebuffer{};
+  GLenum drawBuffer{};
+};
 
 void PyMOLReadPixels(GLint x,
                      GLint y,
@@ -44,15 +50,9 @@ void PyMOLDrawPixels(GLsizei width,
 
 int PyMOLCheckOpenGLErr(const char *pos);
 
-#if defined(_PYMOL_IOS) && !defined(_WEBGL)
-#define VertexIndex_t std::uint16_t
-#define VertexIndex_GL_ENUM GL_UNSIGNED_SHORT
-#define SceneGLClearColor(red,green,blue,alpha) if (!SceneGetBackgroundColorAlreadySet(G)) glClearColor(red,green,blue,alpha);
-#else
 #define VertexIndex_t std::uint32_t
 #define VertexIndex_GL_ENUM GL_UNSIGNED_INT
 #define SceneGLClearColor(red,green,blue,alpha) glClearColor(red,green,blue,alpha);
-#endif
 
 #ifndef GLAPIENTRY
 #define GLAPIENTRY
