@@ -5,6 +5,7 @@
 #include "CGORenderer.h"
 #include "CoordSet.h"
 #include "Feedback.h"
+#include "GraphicsUtil.h"
 #include "Scene.h"
 #include "SceneDef.h"
 #include "ShaderMgr.h"
@@ -12,16 +13,9 @@
 #include "os_gl.h"
 #include "os_gl_cgo.h"
 
-#if defined(_PYMOL_IOS) && !defined(_WEBGL)
-#define ALIGN_VBOS_TO_4_BYTE_ARRAYS
-#define VAR_FOR_NORMAL plc
-#define VAR_FOR_NORMAL_CNT_PLUS +(cnt / 3)
-#define VERTEX_NORMAL_SIZE 4
-#else
 #define VAR_FOR_NORMAL pl
 #define VERTEX_NORMAL_SIZE 3
 #define VAR_FOR_NORMAL_CNT_PLUS
-#endif
 
 #ifdef PURE_OPENGL_ES_2
 #define glVertexAttrib4ubv(loc, data) glVertexAttrib4f(loc, \
@@ -63,26 +57,6 @@ static int CGOConvertDebugMode(int debug, int modeArg)
   return mode;
 }
 
-#if defined(_PYMOL_IOS) && !defined(_WEBGL)
-extern "C" void firePyMOLLimitationWarning();
-#define CHECK_GL_ERROR_OK(printstr)                                            \
-  if ((err = glGetError()) != 0 || I->G->Interrupt != 0) {                     \
-    if (err)                                                                   \
-      PRINTFB(G, FB_CGO, FB_Errors) printstr, err ENDFB(G);                    \
-  }
-#else
-#define CHECK_GL_ERROR_OK(printstr)                                            \
-  if ((err = glGetError()) != 0) {                                             \
-    PRINTFB(G, FB_CGO, FB_Errors) printstr, err ENDFB(G);                      \
-  }
-#endif
-
-void CheckGLErrorOK(PyMOLGlobals* G, pymol::zstring_view errString)
-{
-  GLenum err;
-  CHECK_GL_ERROR_OK(errString.c_str());
-}
-
 static void CGO_gl_begin(CCGORenderer* I, CGO_op_data pc)
 {
 #ifndef PURE_OPENGL_ES_2
@@ -149,7 +123,7 @@ static void CGO_gl_vertex_cross(CCGORenderer* I, CGO_op_data v)
     }
 #ifndef PURE_OPENGL_ES_2
   } else {
-    CSetting *set1 = NULL, *set2 = NULL;
+    CSetting *set1 = nullptr, *set2 = nullptr;
     if (I->rep && I->rep->cs)
       set1 = I->rep->cs->Setting.get();
     if (I->rep && I->rep->obj)
@@ -443,7 +417,7 @@ void TransparentInfoSortIX(PyMOLGlobals* G, float* sum, float* z_value, int* ix,
   int idx;
 
 #ifdef PURE_OPENGL_ES_2
-  copy44f(SceneGetModelViewMatrix(G), matrix);
+  copy44f(SceneGetModelViewMatrixPtr(G), matrix);
 #else
   glGetFloatv(GL_MODELVIEW_MATRIX, matrix);
 #endif
@@ -542,7 +516,7 @@ static void CGO_gl_draw_buffers_indexed(CCGORenderer* I, CGO_op_data pc)
     int* ix = (int*) (z_value + n_tri);
     int* sort_mem = ix + n_tri;
     int t_mode;
-    CSetting *set1 = NULL, *set2 = NULL;
+    CSetting *set1 = nullptr, *set2 = nullptr;
     if (I->rep && I->rep->cs)
       set1 = I->rep->cs->Setting.get();
     if (I->rep && I->rep->obj)
@@ -675,7 +649,7 @@ static void CGO_gl_draw_custom(CCGORenderer* I, CGO_op_data pc)
   VertexBuffer* vbo = I->G->ShaderMgr->getGPUBuffer<VertexBuffer>(sp->vboid);
   if (!vbo)
     return;
-  IndexBuffer* ibo = NULL;
+  IndexBuffer* ibo = nullptr;
   if (sp->iboid) {
     ibo = I->G->ShaderMgr->getGPUBuffer<IndexBuffer>(sp->iboid);
   }
@@ -837,7 +811,7 @@ static void CGO_gl_draw_labels(CCGORenderer* I, CGO_op_data pc)
       I->info ? I->info->pass : RenderPass::Antialias);
   if (I->rep) {
     float label_size;
-    CSetting *set1 = NULL, *set2 = NULL;
+    CSetting *set1 = nullptr, *set2 = nullptr;
     if (I->rep->cs)
       set1 = I->rep->cs->Setting.get();
     if (I->rep->obj)
@@ -899,8 +873,8 @@ static void CGO_gl_draw_connectors(CCGORenderer* I, CGO_op_data pc)
   }
   if (I->rep) {
     float label_size;
-    CSetting *set1 = NULL, *set2 = NULL;
-    float v_scale = SceneGetScreenVertexScale(I->G, NULL);
+    CSetting *set1 = nullptr, *set2 = nullptr;
+    float v_scale = SceneGetScreenVertexScale(I->G, nullptr);
     if (I->rep->cs)
       set1 = I->rep->cs->Setting.get();
     if (I->rep->obj)
@@ -1053,7 +1027,7 @@ static void CGO_gl_linewidth(CCGORenderer* I, CGO_op_data pc)
  * call glLineWidth and set the "line_width" uniform
  */
 static void glLineWidthAndUniform(
-    float line_width, CShaderPrg* shaderPrg = NULL)
+    float line_width, CShaderPrg* shaderPrg = nullptr)
 {
 #ifndef _WEBGL
   glLineWidth(line_width);
@@ -1072,9 +1046,9 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
   bool openVR = SceneGetStereo(I->G) == cStereo_openvr;
   char varwidth = 0;
   float vScale =
-      (I->info ? I->info->vertex_scale : SceneGetScreenVertexScale(I->G, NULL));
+      (I->info ? I->info->vertex_scale : SceneGetScreenVertexScale(I->G, nullptr));
 
-  CSetting *csSetting = NULL, *objSetting = NULL;
+  CSetting *csSetting = nullptr, *objSetting = nullptr;
   auto shaderPrg = I->G->ShaderMgr->Get_Current_Shader();
   if (I->rep && I->rep->cs) {
     csSetting = I->rep->cs->Setting.get();
@@ -1084,7 +1058,7 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
   }
   switch (mode) {
   case LINEWIDTH_DYNAMIC_WITH_SCALE_RIBBON: {
-    float line_width = SettingGet_f(I->G, NULL, NULL, cSetting_ribbon_width);
+    float line_width = SettingGet_f(I->G, nullptr, nullptr, cSetting_ribbon_width);
     if (!openVR)
       line_width = SceneGetDynamicLineWidth(I->info, line_width);
     if (I->info && I->info->width_scale_flag) {
@@ -1093,7 +1067,7 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
     glLineWidthAndUniform(line_width, shaderPrg);
   } break;
   case LINEWIDTH_DYNAMIC_WITH_SCALE_DASH: {
-    float line_width = SettingGet_f(I->G, NULL, NULL, cSetting_dash_width);
+    float line_width = SettingGet_f(I->G, nullptr, nullptr, cSetting_dash_width);
     if (!openVR)
       line_width = SceneGetDynamicLineWidth(I->info, line_width);
     if (I->info && I->info->width_scale_flag) {
@@ -1102,7 +1076,7 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
     glLineWidthAndUniform(line_width, shaderPrg);
   } break;
   case LINEWIDTH_DYNAMIC_WITH_SCALE: {
-    float line_width = SettingGet_f(I->G, NULL, NULL, cSetting_line_width);
+    float line_width = SettingGet_f(I->G, nullptr, nullptr, cSetting_line_width);
     if (!openVR)
       line_width = SceneGetDynamicLineWidth(I->info, line_width);
     if (I->info && I->info->width_scale_flag) {
@@ -1111,7 +1085,7 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
     glLineWidthAndUniform(line_width, shaderPrg);
   } break;
   case LINEWIDTH_WITH_SCALE: {
-    float line_width = SettingGet_f(I->G, NULL, NULL, cSetting_line_width);
+    float line_width = SettingGet_f(I->G, nullptr, nullptr, cSetting_line_width);
     if (I->info && I->info->width_scale_flag) {
       line_width *= I->info->width_scale;
     }
@@ -1123,7 +1097,7 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
       line_width = SettingGet_f(I->G, I->rep->cs->Setting.get(),
           I->rep->obj->Setting.get(), cSetting_mesh_width);
     } else {
-      line_width = SettingGet_f(I->G, NULL, NULL, cSetting_mesh_width);
+      line_width = SettingGet_f(I->G, nullptr, nullptr, cSetting_mesh_width);
     }
     if (!openVR)
       line_width = SceneGetDynamicLineWidth(I->info, line_width);
@@ -1147,12 +1121,12 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
     break;
   }
   case CYLINDERWIDTH_DYNAMIC_MESH: {
-    CSetting* setting = NULL;
+    CSetting* setting = nullptr;
     float mesh_width;
     if (I && I->rep && I->rep->obj) {
       setting = I->rep->obj->Setting.get();
     }
-    mesh_width = SettingGet_f(I->G, setting, NULL, cSetting_mesh_width);
+    mesh_width = SettingGet_f(I->G, setting, nullptr, cSetting_mesh_width);
     if (shaderPrg) {
       const float* color = I->color ? I->color : g_ones4f;
       shaderPrg->Set1f("uni_radius",
@@ -1231,9 +1205,7 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
       radius = dot_width;
     if (shaderPrg)
       shaderPrg->Set1f("g_PointSize", radius);
-#ifndef _PYMOL_IOS
     glPointSize(radius);
-#endif
   } break;
   case DOT_WIDTH_FOR_DOT_SPHERES: {
     float dotSize =
@@ -1341,7 +1313,7 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
   } break;
   case LINEWIDTH_FOR_LINES: {
     float line_width = SceneGetDynamicLineWidth(
-        I->info, SettingGet_f(I->G, NULL, NULL, cSetting_line_width));
+        I->info, SettingGet_f(I->G, nullptr, nullptr, cSetting_line_width));
     if (I->info && I->info->width_scale_flag) {
       line_width *= I->info->width_scale;
     }
@@ -1350,7 +1322,7 @@ static void CGO_gl_special(CCGORenderer* I, CGO_op_data pc)
   case SET_LABEL_SCALE_UNIFORMS: {
     if (I->rep) {
       float label_size;
-      CSetting *set1 = NULL, *set2 = NULL;
+      CSetting *set1 = nullptr, *set2 = nullptr;
       if (I->rep->cs)
         set1 = I->rep->cs->Setting.get();
       if (I->rep->obj)
@@ -1670,8 +1642,7 @@ static void CGO_gl_disable(CCGORenderer* I, CGO_op_data pc)
     case GL_OIT_SHADER:
     case GL_SMAA1_SHADER:
     case GL_SMAA2_SHADER:
-      glBindFramebufferEXT(
-          GL_FRAMEBUFFER_EXT, I->G->ShaderMgr->default_framebuffer_id);
+      I->G->ShaderMgr->setDrawBuffer(I->G->ShaderMgr->topLevelConfig);
       break;
 #endif
     case GL_BACK_FACE_CULLING:
@@ -1741,7 +1712,7 @@ static void CGO_gl_sphere(CCGORenderer* I, CGO_op_data varg)
   if (I->isPicking) {
     SphereRender(I->G, 0, v, I->color, I->alpha, v[3]);
   } else {
-    SphereRender(I->G, I->sphere_quality, v, NULL, I->alpha, v[3]);
+    SphereRender(I->G, I->sphere_quality, v, nullptr, I->alpha, v[3]);
   }
 }
 
@@ -1899,7 +1870,7 @@ static int* get_pickcolorsset_ptr(int op, float* pc)
     RETURN_PICKCOLORSETPTR_CASE(cylinder_buffers);
     RETURN_PICKCOLORSETPTR_CASE(custom);
   }
-  return NULL;
+  return nullptr;
 }
 
 void CGORenderGLPicking(CGO* I, RenderInfo* info, PickContext* context,
@@ -2014,7 +1985,7 @@ void CGORenderGLPicking(CGO* I, RenderInfo* info, PickContext* context,
         int srcp;
         float* pca = nullptr;
         int* pickDataSrc;
-        uchar* pickColorDestUC = NULL;
+        uchar* pickColorDestUC = nullptr;
         bool free_pick_color_dest = false;
         int destOffset = 0, bufsizemult = 1;
         size_t pickvbo = 0;
@@ -2144,7 +2115,7 @@ void CGORenderGLPicking(CGO* I, RenderInfo* info, PickContext* context,
 
         if (free_pick_color_dest) {
           delete[] pickColorDestUC;
-          pickColorDestUC = NULL;
+          pickColorDestUC = nullptr;
           free_pick_color_dest = false;
         }
       }
@@ -2172,8 +2143,8 @@ void CGORenderGL(CGO* I, const float* color, CSetting* set1, CSetting* set2,
 
   if (I->render_alpha) {
     // for now, the render_alpha_only flag calls CGOSetZVector/CGORenderGLAlpha
-    float* ModMatrix = SceneGetModMatrix(G);
-    CGOSetZVector(I, ModMatrix[2], ModMatrix[6], ModMatrix[10]);
+    auto modMatrix = SceneGetModelViewMatrixPtr(G);
+    CGOSetZVector(I, modMatrix[2], modMatrix[6], modMatrix[10]);
     CGORenderAlpha(I, info, 1);
     if (I->render_alpha == 1) // right now, render_alpha 1: renders alpha only,
                               // 2: renders both alpha and rest
@@ -2248,11 +2219,11 @@ void CGORenderGL(CGO* I, const float* color, CSetting* set1, CSetting* set2,
         int mode = -1;
         int vc = 0;
         // triangle normals
-        const float *n0 = NULL, *n1 = NULL, *n2 = NULL;
+        const float *n0 = nullptr, *n1 = nullptr, *n2 = nullptr;
         // triangle vertices
-        const float *v0 = NULL, *v1 = NULL, *v2 = NULL;
+        const float *v0 = nullptr, *v1 = nullptr, *v2 = nullptr;
         // triangle colors
-        const float *c0 = color, *c1 = NULL, *c2 = NULL;
+        const float *c0 = color, *c1 = nullptr, *c2 = nullptr;
 
         for (auto it = I->begin(); !it.is_stop(); ++it) {
           const auto op = it.op_code();
@@ -2537,7 +2508,7 @@ void CGORenderGLAlpha(CGO* I, RenderInfo* info, bool calcDepth)
             float* const pc = it.data();
             assert(base < pc && pc < I->op + I->c);
             auto i =
-                pymol::clamp<int>((pc[4] - I->z_min) * range_factor, 0, i_size);
+                std::clamp<int>((pc[4] - I->z_min) * range_factor, 0, i_size);
             CGO_put_int(pc, start[i]);
             start[i] = (pc - base); /* NOTE: will always be > 0 since we have
                                        CGO_read_int'd */
