@@ -17,29 +17,31 @@ Z* -------------------------------------------------------------------
 #ifndef _H_Extrude
 #define _H_Extrude
 
-#include"Ray.h"
-#include"CGO.h"
-#include"ObjectMolecule.h"
-#include"CoordSet.h"
+#include "Basis.h"
 
-typedef struct {
-  PyMOLGlobals *G;
-  int N;                        /* number of points in the extrusion segment */
+struct PyMOLGlobals;
+struct ObjectMolecule;
+class CGO;
 
-  float *p;                     /* points */
-  float *n;                     /* normals (3x3f) at each point */
-  float *c;                     /* colors */
-  float *alpha;                 /* alpha values*/
-  unsigned int *i;              /* atom indices */
+struct CExtrude {
+  PyMOLGlobals* G{};
+  int N{}; /* number of points in the extrusion segment */
 
-  float r;
-  float *sf;                    /* scale factors for variable-width extrusions (single point) */
+  float* p{};        /* points */
+  float* n{};        /* normals (3x3f) at each point */
+  float* c{};        /* colors */
+  float* alpha{};    /* alpha values*/
+  unsigned int* i{}; /* atom indices */
 
-  float *sv, *tv;
-  float *sn, *tn;
+  float r{};
+  float* sf{}; /* scale factors for variable-width extrusions (single point) */
+
+  float* sv{};
+  float* tv{};
+  float* sn{};
+  float* tn{};
   int Ns;
-
-} CExtrude;
+};
 
 CExtrude *ExtrudeNew(PyMOLGlobals * G);
 
