@@ -63,10 +63,10 @@ void MovieViewReinterpolate(PyMOLGlobals *G)
   float linear = SettingGetGlobal_f(G, cSetting_motion_linear);
   int hand     = SettingGetGlobal_i(G, cSetting_motion_hand);
 
-  MovieView(G, 3, -1, -1, power, bias, 1, /* note simple always = 1 for camera motion...*/
+  MovieView(G, MViewAction::Reinterpolate, -1, -1, power, bias, 1, /* note simple always = 1 for camera motion...*/
             linear, 
             SettingGetGlobal_b(G,cSetting_movie_loop) ? 1 : 0 ,
-            hand, 5, 1, NULL, 0.5, -1, 1); 
+            hand, 5, 1, nullptr, 0.5, -1, 1); 
 }
 
 int MovieXtoFrame(PyMOLGlobals *G, BlockRect *rect, int frames, int x, int nearest)
@@ -86,14 +86,14 @@ void MovieViewTrim(PyMOLGlobals *G,int n_frame)
 }
 
 
-int MovieViewModify(PyMOLGlobals *G,int action, int index, int count,int target, int freeze, int localize)
+int MovieViewModify(PyMOLGlobals *G, ViewElemAction action, int index, int count,int target, int freeze, int localize)
 {
   CMovie *I = G->Movie;
   int ok = true;
   MovieClearImages(G);
   if( (ok = ViewElemModify(G,&I->ViewElem, action, index, count, target)) ) {
-    switch(action) {
-    case cViewElemModifyInsert:
+    switch (action) {
+    case ViewElemAction::Insert:
       if (index >= 0 && index < I->NFrame) {
         I->Sequence.insert(index, count);
         I->Cmd.insert(I->Cmd.begin() + index, count, "");
@@ -106,7 +106,7 @@ int MovieViewModify(PyMOLGlobals *G,int action, int index, int count,int target,
         }
       }
       break;
-    case cViewElemModifyDelete:
+    case ViewElemAction::Delete:
       if (index >= 0 && index < I->NFrame) {
         I->Sequence.erase(index, count);
         int end_pos = std::min(index + count, static_cast<int>(I->Cmd.size()));
@@ -114,7 +114,7 @@ int MovieViewModify(PyMOLGlobals *G,int action, int index, int count,int target,
         I->NFrame = VLAGetSize(I->Sequence);
       }
       break;
-    case cViewElemModifyMove:
+    case ViewElemAction::Move:
       if((index>=0) && (target>=0) && (index<I->NFrame) && (target<I->NFrame)) {
         int i;
         for(i=0;i<count;i++) {
@@ -134,7 +134,7 @@ int MovieViewModify(PyMOLGlobals *G,int action, int index, int count,int target,
         }
       }
       break;
-    case cViewElemModifyCopy:
+    case ViewElemAction::Copy:
       if((index>=0) && (target>=0) && (index<I->NFrame) && (target<I->NFrame)) {
         int i;
         for(i=0;i<count;i++) {
@@ -213,7 +213,7 @@ void MovieCopyPrepare(PyMOLGlobals * G, int *width, int *height, int *length)
   SettingSetGlobal_i(G, cSetting_overlay, 5);
   nFrame = I->NFrame;
   if(!nFrame) {
-    nFrame = SceneGetNFrame(G, NULL);
+    nFrame = SceneGetNFrame(G, nullptr);
   }
   start = 0;
   stop = nFrame;
@@ -274,7 +274,7 @@ int MovieCopyFrame(PyMOLGlobals * G, int frame, int width, int height, int rowby
   int nFrame;
   nFrame = I->NFrame;
   if(!nFrame) {
-    nFrame = SceneGetNFrame(G, NULL);
+    nFrame = SceneGetNFrame(G, nullptr);
   }
 
   if((frame < nFrame) && (ptr)) {
@@ -333,7 +333,7 @@ int MoviePurgeFrame(PyMOLGlobals * G, int frame)
   int i;
   nFrame = I->NFrame;
   if(!nFrame) {
-    nFrame = SceneGetNFrame(G, NULL);
+    nFrame = SceneGetNFrame(G, nullptr);
   }
   if(!I->CacheSave) {
     if(frame < nFrame) {
@@ -411,7 +411,7 @@ static int MovieCmdFromPyList(PyMOLGlobals * G, PyObject * list, int *warning)
   int warn = false;
 
   if(ok)
-    ok = (list != NULL);
+    ok = (list != nullptr);
   if(ok)
     ok = PyList_Check(list);
 
@@ -463,7 +463,7 @@ int MovieFromPyList(PyMOLGlobals * G, PyObject * list, int *warning)
   if(ok && (ll > 6)) {
     PyObject *tmp;
     VLAFreeP(I->ViewElem);
-    I->ViewElem = NULL;
+    I->ViewElem = nullptr;
     tmp = PyList_GetItem(list, 6);
     if(tmp && !(tmp == Py_None))
       ok = ViewElemVLAFromPyList(G, tmp, &I->ViewElem, I->NFrame);
@@ -483,7 +483,7 @@ static PyObject *MovieCmdAsPyList(PyMOLGlobals * G)
 {
 
   CMovie *I = G->Movie;
-  PyObject *result = NULL;
+  PyObject *result = nullptr;
   int a;
 
   result = PyList_New(I->NFrame);
@@ -499,7 +499,7 @@ static PyObject *MovieCmdAsPyList(PyMOLGlobals * G)
 PyObject *MovieAsPyList(PyMOLGlobals * G)
 {
   CMovie *I = G->Movie;
-  PyObject *result = NULL;
+  PyObject *result = nullptr;
 
   result = PyList_New(7);
   PyList_SetItem(result, 0, PyInt_FromLong(I->NFrame));
@@ -509,17 +509,17 @@ PyObject *MovieAsPyList(PyMOLGlobals * G)
   if(I->Sequence) {
     PyList_SetItem(result, 4, PConvIntArrayToPyList(I->Sequence, I->NFrame));
   } else {
-    PyList_SetItem(result, 4, PConvAutoNone(NULL));
+    PyList_SetItem(result, 4, PConvAutoNone(nullptr));
   }
   if(!I->Cmd.empty()) {
     PyList_SetItem(result, 5, MovieCmdAsPyList(G));
   } else {
-    PyList_SetItem(result, 5, PConvAutoNone(NULL));
+    PyList_SetItem(result, 5, PConvAutoNone(nullptr));
   }
   if(I->ViewElem) {
     PyList_SetItem(result, 6, ViewElemVLAAsPyList(G, I->ViewElem, I->NFrame));
   } else {
-    PyList_SetItem(result, 6, PConvAutoNone(NULL));
+    PyList_SetItem(result, 6, PConvAutoNone(nullptr));
   }
 
 
@@ -561,7 +561,7 @@ void MoviePlay(PyMOLGlobals * G, int cmd)
     if(I->Playing && !SettingGetGlobal_b(G, cSetting_movie_loop)) {
       /* if not looping, and at end of movie, then automatically rewind
          and force execution of the first movie command */
-      if((SettingGetGlobal_i(G, cSetting_frame)) == (SceneGetNFrame(G, NULL))) {
+      if((SettingGetGlobal_i(G, cSetting_frame)) == (SceneGetNFrame(G, nullptr))) {
         SceneSetFrame(G, 7, 0);
       }
     }
@@ -573,7 +573,7 @@ void MoviePlay(PyMOLGlobals * G, int cmd)
     if(!SettingGetGlobal_b(G, cSetting_movie_loop)) {
       /* if not looping, and at end of movie, then automatically rewind
          and force execution of the first movie command */
-      if((SettingGetGlobal_i(G, cSetting_frame)) == (SceneGetNFrame(G, NULL))) {
+      if((SettingGetGlobal_i(G, cSetting_frame)) == (SceneGetNFrame(G, nullptr))) {
         SceneSetFrame(G, 7, 0);
       }
     }
@@ -635,7 +635,7 @@ static void MovieModalPNG(PyMOLGlobals * G, CMovie * I, CMovieModal * M)
     OrthoBusyPrime(G);
     M->nFrame = I->NFrame;
     if(!M->nFrame) {
-      M->nFrame = SceneGetNFrame(G, NULL);
+      M->nFrame = SceneGetNFrame(G, nullptr);
       if(M->nFrame < 1) {
         M->nFrame = 1;
       }
@@ -855,7 +855,9 @@ int MoviePNG(PyMOLGlobals * G, const char* prefix, int save, int start,
     SettingSetGlobal_b(G, cSetting_seq_view, 0);
     // force viewport update
     SeqChanged(G);
-    OrthoDoDraw(G, OrthoRenderMode::Main);
+    OrthoDrawInfo drawInfo{};
+    drawInfo.renderMode = OrthoRenderMode::Main;
+    OrthoDoDraw(G, drawInfo);
   }
 
   M->modal = modal;
@@ -1083,7 +1085,7 @@ void MovieSetCommand(PyMOLGlobals* G, int frame, const char* command)
 
 
 /*========================================================================*/
-int MovieView(PyMOLGlobals * G, int action, int first,
+int MovieView(PyMOLGlobals * G, MViewAction action, int first,
               int last, float power, float bias,
               int simple, float linear, int wrap,
               int hand, int window, int cycles,
@@ -1095,43 +1097,43 @@ int MovieView(PyMOLGlobals * G, int action, int first,
   if(wrap<0) {
     wrap = SettingGetGlobal_b(G,cSetting_movie_loop);
   }
-  if((action == 7) || (action == 8)) { /* toggle */
+  if (action == MViewAction::Toggle || action == MViewAction::ToggleInterp) {
     frame = first;
     if(first < 0)
       frame = SceneGetFrame(G);
     VLACheck(I->ViewElem, CViewElem, frame);
-    if(action == 7) {
+    if (action == MViewAction::Toggle) {
       if(I->ViewElem[frame].specification_level>1) {
-        action = 1;
+        action = MViewAction::Clear;
       } else {
-        action = 0;
+        action = MViewAction::Store;
       }
-    } else if(action == 8) {
+    } else if (action == MViewAction::ToggleInterp) {
       if(I->ViewElem[frame].specification_level>1) {
         int frame;
-        action = 3;
+        action = MViewAction::Reinterpolate;
         for(frame=0;frame<I->NFrame;frame++) {
           if(I->ViewElem[frame].specification_level==1) {
-            action = 6;
+            action = MViewAction::Uninterpolate;
             break;
           }
         }
       }
       else if(I->ViewElem[frame].specification_level>0) {
-        action = 6;
+        action = MViewAction::Uninterpolate;
       } else {
-        action = 3;
+        action = MViewAction::Reinterpolate;
       }
     }
   }
-  if(action == 4) {
+  if(action == MViewAction::Smooth) {
     if(I->ViewElem) {
       int save_last = last;
       if(first < 0)
         first = 0;
       
       if(last < 0) {
-        last = SceneGetNFrame(G, NULL) - 1;
+        last = SceneGetNFrame(G, nullptr) - 1;
       }
       if(last >= I->NFrame) {
         last = I->NFrame - 1;
@@ -1144,13 +1146,13 @@ int MovieView(PyMOLGlobals * G, int action, int first,
         }
       }
       if(SettingGetGlobal_b(G, cSetting_movie_auto_interpolate)) {
-        action = 3; /* reinterpolate */
+        action = MViewAction::Reinterpolate;
         last = save_last;
       }
     }
   }
   switch (action) {
-  case 0:                      /* store */
+  case MViewAction::Store:                      /* store */
     if(I->ViewElem) {
       if(first < 0)
         first = SceneGetFrame(G);
@@ -1167,7 +1169,7 @@ int MovieView(PyMOLGlobals * G, int action, int first,
               " MovieView: Setting frame %d.\n", frame + 1 ENDFB(G);
           }
           if(scene_name && (!scene_name[0]))
-            scene_name = NULL;
+            scene_name = nullptr;
           SceneToViewElem(G, I->ViewElem + frame, scene_name);
           if(state>=0) {
             I->ViewElem[frame].state = state;
@@ -1192,7 +1194,7 @@ int MovieView(PyMOLGlobals * G, int action, int first,
       }
     }
     break;
-  case 1:                      /* clear */
+  case MViewAction::Clear:
     if(I->ViewElem) {
       if(first < 0)
         first = SceneGetFrame(G);
@@ -1207,13 +1209,12 @@ int MovieView(PyMOLGlobals * G, int action, int first,
       }
     }
     break;
-  case 2:                      /* interpolate & reinterpolate */
-  case 3:
+  case MViewAction::Interpolate:
+  case MViewAction::Reinterpolate:
     if(I->ViewElem) {
       int view_found = false;
-      CViewElem *first_view = NULL, *last_view = NULL;
-      if(first < 0)
-        first = 0;
+      CViewElem *first_view = nullptr, *last_view = nullptr;
+      first = std::max(0, first);
 
       if(first > I->NFrame) {
         first = I->NFrame - 1;
@@ -1265,7 +1266,7 @@ int MovieView(PyMOLGlobals * G, int action, int first,
       }
 
       if(!quiet) {
-        if(action == 2) {
+        if(action == MViewAction::Interpolate) {
           if(last == I->NFrame) {
             PRINTFB(G, FB_Movie, FB_Details)
               " MovieView: interpolating unspecified frames %d to %d (wrapping)\n",
@@ -1300,7 +1301,7 @@ int MovieView(PyMOLGlobals * G, int action, int first,
           int interpolate_flag = false;
           if(I->ViewElem[frame].specification_level == 2) {     /* specified */
             last_view = I->ViewElem + frame;
-            if(action == 2) {   /* interpolate */
+            if (action == MViewAction::Interpolate) {
               for(view = first_view + 1; view < last_view; view++) {
                 if(!view->specification_level)
                   interpolate_flag = true;
@@ -1313,7 +1314,7 @@ int MovieView(PyMOLGlobals * G, int action, int first,
                                   power, bias, simple, linear, hand, scene_cut);
             }
             first_view = last_view;
-            last_view = NULL;
+            last_view = nullptr;
           }
         }
       }
@@ -1340,18 +1341,17 @@ int MovieView(PyMOLGlobals * G, int action, int first,
       }
     }
     break;
-  case 5:                      /* reset */
+  case MViewAction::Reset:
     if(I->ViewElem) {
       int size = VLAGetSize(I->ViewElem);
       I->ViewElem = pymol::vla<CViewElem>(size);
     }
     break;
-  case 6:                      /* uninterpolate */
+  case MViewAction::Uninterpolate:
     if(I->ViewElem) {
-      if(first < 0)
-        first = 0;
+      first = std::max(0, first);
       if(last < 0) {
-        last = SceneGetNFrame(G, NULL) - 1;
+        last = SceneGetNFrame(G, nullptr) - 1;
       }
       for(frame = first; frame <= last; frame++) {
         if((frame >= 0) && (frame < I->NFrame)) {
