@@ -29,9 +29,12 @@ Z* -------------------------------------------------------------------
 #include"SceneView.h"
 #include"Rect.h"
 #include "Camera.h"
+#include "Spatial.h"
 #include<list>
 #include<vector>
 
+#include <glm/mat4x4.hpp>
+
 #define TRN_BKG 0x30
 #define MAX_ANI_ELEM 300
 
@@ -45,25 +48,6 @@ typedef struct {
 } SceneUnitContext;
 
 
-struct Offset2D
-{
-  std::int32_t x;
-  std::int32_t y;
-};
-
-struct Extent2D
-{
-  std::uint32_t width;
-  std::uint32_t height;
-};
-
-struct Rect2D
-{
-  Offset2D offset;
-  Extent2D extent;
-};
-
-
 inline bool operator==(const Rect2D& rectA, const Rect2D& rectB) {
   return rectA.offset.x == rectB.offset.x && rectA.offset.y == rectB.offset.y &&
          rectA.extent.width == rectB.extent.width &&
@@ -91,7 +75,8 @@ struct GridInfo {
 
 using PrepareViewportForStereoFuncT = void (*)(
     PyMOLGlobals*, CScene*, int, bool, int, const Offset2D&,
-    const Extent2D&);
+    const std::optional<Rect2D>&);
+
 
 class CScene : public Block {
  public:
@@ -170,15 +155,10 @@ class CScene : public Block {
   short prev_no_z_rotation1{}, prev_no_z_rotation2{};
   int orig_x_rotation{}, orig_y_rotation{};
 
-  std::vector<float> m_ModelViewMatrixStack;
-  int m_ModelViewMatrixStackDepth { 0 };
+  std::vector<glm::mat4> m_ModelViewMatrixStack;
+  glm::mat4 modelViewMatrix{};
 
-  union {
-    float ModelViewMatrix[16]{};
-    float ModMatrix[16];          // old alias, deprecated
-  };
-
-  float ProjectionMatrix[16]{};
+  glm::mat4 projectionMatrix{};
   int background_color_already_set{};
   int do_not_clear{};
   GridInfo grid{};
@@ -189,7 +169,7 @@ class CScene : public Block {
   CGO *offscreenOIT_CGO_copy { nullptr };
   PrepareViewportForStereoFuncT vp_prepareViewPortForStereo = nullptr;
   Offset2D vp_pos{};
-  Extent2D vp_oversize{};
+  std::optional<Rect2D> vp_oversize{};
   int vp_times{}, vp_stereo_mode{};
   float vp_width_scale{};
   PickColorManager pickmgr;
