@@ -759,7 +759,7 @@ enum {
   REC_s( 659, default_2fofc_map_rep                   , global    , "volume" ),
   REC_s( 660, atom_type_format                        , global    , "mol2" ),
   REC_b( 661, autoclose_dialogs                       , global    , 1 ),
-  REC_b( 662, bg_gradient                             , global    , 0 ),
+  REC_i( 662, bg_gradient                             , global    , 0 ),
   REC_c( 663, bg_rgb_top                              , global    , "0x00004D" ),
   REC_c( 664, bg_rgb_bottom                           , global    , "0x333380" ),
   REC_b( 665, ray_volume                              , global    , 0 ),
@@ -895,7 +895,16 @@ enum {
   REC_i( 785, cartoon_smooth_cylinder_cycles          , global    , 3 ),
   REC_i( 786, cartoon_smooth_cylinder_window          , global    , 2 ),
   REC_i( 787, isosurface_algorithm                    , global    , 0, 0, 2 ),
-
+  REC_b( 788, cell_centered                           , global    , false ),
+  REC_f( 789, halogen_bond_distance                       , global    , 3.5f ),
+  REC_f( 790, halogen_bond_as_donor_min_donor_angle       , global    , 140.0f ),
+  REC_f( 791, halogen_bond_as_donor_min_acceptor_angle    , global    , 90.0f ),
+  REC_f( 792, halogen_bond_as_acceptor_min_donor_angle    , global    , 120.0f ),
+  REC_f( 793, halogen_bond_as_acceptor_min_acceptor_angle , global    , 90.0f ),
+  REC_f( 794, halogen_bond_as_acceptor_max_acceptor_angle , global    , 170.0f ),
+  REC_f( 795, salt_bridge_distance                        , global    , 5.0f ),
+  REC_b( 796, use_tessellation_shaders                , global    , true ),
+  REC_c( 797, cell_color                              , ostate    , "-1" ),
 
 #ifdef SETTINGINFO_IMPLEMENTATION
 #undef SETTINGINFO_IMPLEMENTATION
