@@ -30,7 +30,8 @@ Z* -------------------------------------------------------------------
 #include"Ortho.h"
 #include"CGO.h"
 
-int ViewElemModify(PyMOLGlobals *G, CViewElem **handle, int action, int index, int count, int target)
+int ViewElemModify(PyMOLGlobals* G, CViewElem** handle, ViewElemAction action, int index,
+    int count, int target)
 {
   int ok = true;
   CViewElem *vla = *handle;
@@ -39,14 +40,14 @@ int ViewElemModify(PyMOLGlobals *G, CViewElem **handle, int action, int index, i
   }
   if(vla) {
     int n_frame = VLAGetSize(vla);
-    switch(action) {
-    case cViewElemModifyInsert: 
+    switch (action) {
+    case ViewElemAction::Insert: 
       VLAInsert(vla,CViewElem,index,count);
       break;
-    case cViewElemModifyDelete:
+    case ViewElemAction::Delete:
       VLADelete(vla,CViewElem,index,count);
       break;
-    case cViewElemModifyMove:
+    case ViewElemAction::Move:
       if((index>=0) && (target>=0) && (index<n_frame) && (target<n_frame)) {
         if((count>1)||(vla[index].specification_level>1)) {
           
@@ -68,7 +69,7 @@ int ViewElemModify(PyMOLGlobals *G, CViewElem **handle, int action, int index, i
         }
       }
       break;
-    case cViewElemModifyCopy:
+    case ViewElemAction::Copy:
       if((index>=0) && (target>=0) && (index<n_frame) && (target<n_frame)) {
         if((count>1)||(vla[index].specification_level>1)) {
           int i;
@@ -340,9 +341,9 @@ void ViewElemArrayPurge(PyMOLGlobals * G, CViewElem * view, int nFrame)
 PyObject *ViewElemAsPyList(PyMOLGlobals * G, const CViewElem * view)
 {
 #ifdef _PYMOL_NOPY
-  return NULL;
+  return nullptr;
 #else
-  PyObject *result = NULL;
+  PyObject *result = nullptr;
 
   result = PyList_New(21);
 
@@ -351,21 +352,21 @@ PyObject *ViewElemAsPyList(PyMOLGlobals * G, const CViewElem * view)
     if(view->matrix_flag) {
       PyList_SetItem(result, 1, PConvDoubleArrayToPyList(view->matrix, 16));
     } else {
-      PyList_SetItem(result, 1, PConvAutoNone(NULL));
+      PyList_SetItem(result, 1, PConvAutoNone(nullptr));
     }
 
     PyList_SetItem(result, 2, PyInt_FromLong(view->pre_flag));
     if(view->pre_flag) {
       PyList_SetItem(result, 3, PConvDoubleArrayToPyList(view->pre, 3));
     } else {
-      PyList_SetItem(result, 3, PConvAutoNone(NULL));
+      PyList_SetItem(result, 3, PConvAutoNone(nullptr));
     }
 
     PyList_SetItem(result, 4, PyInt_FromLong(view->post_flag));
     if(view->post_flag) {
       PyList_SetItem(result, 5, PConvDoubleArrayToPyList(view->post, 3));
     } else {
-      PyList_SetItem(result, 5, PConvAutoNone(NULL));
+      PyList_SetItem(result, 5, PConvAutoNone(nullptr));
     }
 
     PyList_SetItem(result, 6, PyInt_FromLong(view->clip_flag));
@@ -373,15 +374,15 @@ PyObject *ViewElemAsPyList(PyMOLGlobals * G, const CViewElem * view)
       PyList_SetItem(result, 7, PyFloat_FromDouble((double) view->front));
       PyList_SetItem(result, 8, PyFloat_FromDouble((double) view->back));
     } else {
-      PyList_SetItem(result, 7, PConvAutoNone(NULL));
-      PyList_SetItem(result, 8, PConvAutoNone(NULL));
+      PyList_SetItem(result, 7, PConvAutoNone(nullptr));
+      PyList_SetItem(result, 8, PConvAutoNone(nullptr));
     }
 
     PyList_SetItem(result, 9, PyInt_FromLong(view->ortho_flag));
     if(view->ortho_flag) {
       PyList_SetItem(result, 10, PyFloat_FromDouble(view->ortho));
     } else {
-      PyList_SetItem(result, 10, PConvAutoNone(NULL));
+      PyList_SetItem(result, 10, PConvAutoNone(nullptr));
     }
 
     PyList_SetItem(result, 11, PyInt_FromLong(view->view_mode));
@@ -404,21 +405,21 @@ PyObject *ViewElemAsPyList(PyMOLGlobals * G, const CViewElem * view)
     if(view->ortho_flag) {
       PyList_SetItem(result, 16, PyFloat_FromDouble(view->power));
     } else {
-      PyList_SetItem(result, 16, PConvAutoNone(NULL));
+      PyList_SetItem(result, 16, PConvAutoNone(nullptr));
     }
 
     PyList_SetItem(result, 17, PyInt_FromLong(view->bias_flag));
     if(view->bias_flag) {
       PyList_SetItem(result, 18, PyFloat_FromDouble(view->bias));
     } else {
-      PyList_SetItem(result, 18, PConvAutoNone(NULL));
+      PyList_SetItem(result, 18, PConvAutoNone(nullptr));
     }
 
     PyList_SetItem(result, 19, PyInt_FromLong(view->state_flag));
     if(view->state_flag) {
       PyList_SetItem(result, 20, PyInt_FromLong(view->state));
     } else {
-      PyList_SetItem(result, 20, PConvAutoNone(NULL));
+      PyList_SetItem(result, 20, PConvAutoNone(nullptr));
     }
 
   }
@@ -433,7 +434,7 @@ int ViewElemFromPyList(PyMOLGlobals * G, PyObject * list, CViewElem * view)
   ov_size ll = 0;
 
   if(ok)
-    ok = (list != NULL);
+    ok = (list != nullptr);
   if(ok)
     ok = PyList_Check(list);
   if(ok)
@@ -483,7 +484,7 @@ int ViewElemFromPyList(PyMOLGlobals * G, PyObject * list, CViewElem * view)
     if(ok)
       ok = PConvPyIntToInt(PyList_GetItem(list, 13), &view->scene_flag);
     if(ok && view->scene_flag) {
-      const char *ptr = NULL;
+      const char *ptr = nullptr;
       view->scene_flag = false;
       if(PConvPyStrToStrPtr(PyList_GetItem(list, 14), &ptr)) {
         OVreturn_word result = OVLexicon_GetFromCString(G->Lexicon, ptr);
@@ -525,15 +526,15 @@ int ViewElemVLAFromPyList(PyMOLGlobals * G, PyObject * list, CViewElem ** vla_pt
                           int nFrame)
 {
   int ok = true;
-  CViewElem *vla = NULL;
+  CViewElem *vla = nullptr;
   if(ok)
-    ok = (list != NULL);
+    ok = (list != nullptr);
   if(ok)
     ok = PyList_Check(list);
   if(ok)
     ok = (PyList_Size(list) == nFrame);
   if(ok)
-    ok = ((vla = VLACalloc(CViewElem, nFrame)) != NULL);
+    ok = ((vla = VLACalloc(CViewElem, nFrame)) != nullptr);
   if(ok) {
     int a;
     for(a = 0; a < nFrame; a++) {
@@ -553,10 +554,10 @@ int ViewElemVLAFromPyList(PyMOLGlobals * G, PyObject * list, CViewElem ** vla_pt
 PyObject *ViewElemVLAAsPyList(PyMOLGlobals * G, const CViewElem * vla, int nFrame)
 {
 #ifdef _PYMOL_NOPY
-  return NULL;
+  return nullptr;
 #else
 
-  PyObject *result = NULL;
+  PyObject *result = nullptr;
   int a;
   result = PyList_New(nFrame);
   for(a = 0; a < nFrame; a++) {
@@ -587,7 +588,7 @@ CViewIterator ViewGetIterator(CView * I)
 int ViewIterate(CView * I, CViewIterator * iter, CRay * ray, int at_least_once)
 {
   int result;
-  CViewElem *elem = NULL;
+  CViewElem *elem = nullptr;
 
   if((!I) || (!I->NView)) {     /* trusting short-circuit to avoid segfault */
     if(at_least_once) {
