@@ -20,7 +20,7 @@ Z* -------------------------------------------------------------------
 #include"os_std.h"
 #include"os_gl.h"
 
-#include"OOMac.h"
+#include"Err.h"
 #include"ObjectCGO.h"
 #include"Base.h"
 #include"MemoryDebug.h"
@@ -32,22 +32,23 @@ Z* -------------------------------------------------------------------
 #include"Color.h"
 #include"VFont.h"
 #include"ShaderMgr.h"
+#include "Feedback.h"
 
 static PyObject *ObjectCGOStateAsPyList(ObjectCGOState * I)
 {
-  PyObject *result = NULL;
+  PyObject *result = nullptr;
 
   result = PyList_New(1);
   if(I->origCGO)
     PyList_SetItem(result, 0, CGOAsPyList(I->origCGO.get()));
   else
-    PyList_SetItem(result, 0, PConvAutoNone(NULL));
+    PyList_SetItem(result, 0, PConvAutoNone(nullptr));
   return (PConvAutoNone(result));
 }
 
 static PyObject *ObjectCGOAllStatesAsPyList(ObjectCGO * I)
 {
-  PyObject *result = NULL;
+  PyObject *result = nullptr;
   int a;
   result = PyList_New(I->State.size());
   for(a = 0; a < I->State.size(); a++) {
@@ -63,7 +64,7 @@ static int ObjectCGOStateFromPyList(PyMOLGlobals * G, ObjectCGOState * I, PyObje
   int ll, pl = 0;
   PyObject *tmp;
   if(ok)
-    ok = (list != NULL);
+    ok = (list != nullptr);
   if(ok)
     ok = PyList_Check(list);
   if(ok)
@@ -117,16 +118,16 @@ int ObjectCGONewFromPyList(PyMOLGlobals * G, PyObject * list, ObjectCGO ** resul
                            int version)
 {
   int ok = true;
-  ObjectCGO *I = NULL;
-  (*result) = NULL;
+  ObjectCGO *I = nullptr;
+  (*result) = nullptr;
   if(ok)
-    ok = (list != NULL);
+    ok = (list != nullptr);
   if(ok)
     ok = PyList_Check(list);
 
   I = new ObjectCGO(G);
   if(ok)
-    ok = (I != NULL);
+    ok = (I != nullptr);
 
   if(ok){
     auto *val = PyList_GetItem(list, 0);
@@ -148,7 +149,7 @@ int ObjectCGONewFromPyList(PyMOLGlobals * G, PyObject * list, ObjectCGO ** resul
 
 PyObject *ObjectCGOAsPyList(ObjectCGO * I)
 {
-  PyObject *result = NULL;
+  PyObject *result = nullptr;
 
   result = PyList_New(3);
   PyList_SetItem(result, 0, ObjectAsPyList(I));
@@ -234,11 +235,11 @@ static void ObjectCGORenderState(PyMOLGlobals* G, RenderPass pass, CRay* ray,
   if(ray) {
     if(sobj) {
       if(sobj->origCGO){
-        CGO *cgo = sobj->origCGO.get(), *cgo_copy = NULL;
+        CGO *cgo = sobj->origCGO.get(), *cgo_copy = nullptr;
         if (cgo_lighting && CGOHasAnyTriangleVerticesWithoutNormals(cgo)) {
           cgo = cgo_copy = CGOGenerateNormalsForTriangles(cgo);
         }
-        CGORenderRay(cgo, ray, info, color, ramp, I->Setting.get(), NULL);
+        CGORenderRay(cgo, ray, info, color, ramp, I->Setting.get(), nullptr);
         CGOFree(cgo_copy);
       }
     }
@@ -247,14 +248,14 @@ static void ObjectCGORenderState(PyMOLGlobals* G, RenderPass pass, CRay* ray,
       PickContext context;
       context.object = I;
       context.state = sobj - I->State.data();
-      CGORenderGLPicking(sobj->renderCGO.get(), info, &context, I->Setting.get(), nullptr);
+      CGORenderPicking(sobj->renderCGO.get(), info, &context, I->Setting.get(), nullptr);
     } else if (pass != RenderPass::Antialias) {
       bool pass_is_opaque = pass == RenderPass::Opaque;
       if(sobj && ((sobj->hasTransparency ^ pass_is_opaque) || (sobj->hasOpaque == pass_is_opaque))){
 	{
 	  CShaderPrg *shaderPrg;
-	  int two_sided_lighting = SettingGet_i(G, I->Setting.get(), NULL, cSetting_two_sided_lighting);
-          bool backface_cull = SettingGet_i(G, I->Setting.get(), NULL, cSetting_backface_cull);
+	  int two_sided_lighting = SettingGet_i(G, I->Setting.get(), nullptr, cSetting_two_sided_lighting);
+          bool backface_cull = SettingGet_i(G, I->Setting.get(), nullptr, cSetting_backface_cull);
 	  if (two_sided_lighting<0){
 	    two_sided_lighting = !cgo_lighting;
 	  }
@@ -287,12 +288,12 @@ static void ObjectCGORenderState(PyMOLGlobals* G, RenderPass pass, CRay* ray,
 	    shaderPrg->Set1i("two_sided_lighting_enabled", two_sided_lighting);
 	    sobj->renderCGO->use_shader = use_shader;
 	    sobj->renderCGO->debug = SettingGetGlobal_i(G, cSetting_cgo_debug);
-	    CGORenderGL(sobj->renderCGO.get(), color, I->Setting.get(), NULL, info, NULL);
+	    CGORender(sobj->renderCGO.get(), color, I->Setting.get(), nullptr, info, nullptr);
 	    shaderPrg->Disable();
 	  } else {
 	    sobj->renderCGO->use_shader = use_shader;
 	    sobj->renderCGO->debug = SettingGetGlobal_i(G, cSetting_cgo_debug);
-	    CGORenderGL(sobj->renderCGO.get(), color, I->Setting.get(), NULL, info, NULL);
+	    CGORender(sobj->renderCGO.get(), color, I->Setting.get(), nullptr, info, nullptr);
 	  }
 	    if (backface_cull){
 	      glDisable(GL_CULL_FACE);
@@ -329,13 +330,14 @@ static void ObjectCGOGenerateCGO(PyMOLGlobals * G, ObjectCGO * I, ObjectCGOState
     } else {
       colorWithA[0] = 1.f; colorWithA[1] = 1.f; colorWithA[2] = 1.f;
     }
-    colorWithA[3] = 1.f - SettingGet_f(G, I->Setting.get(), NULL, cSetting_cgo_transparency);
+    colorWithA[3] = 1.f - SettingGet_f(G, I->Setting.get(), nullptr, cSetting_cgo_transparency);
 
     bool hasTransparency = (colorWithA[3] < 1.f || CGOHasTransparency(sobj->origCGO.get()));
     bool hasOpaque = (colorWithA[3] == 1.f || CGOHasOpaque(sobj->origCGO.get()));
 
-    CGO *allCylinders = NULL;
-    CGO *allSpheres = NULL;
+    CGO *allCylinders = nullptr;
+    CGO *allSpheres = nullptr;
+    CGO* allBeziers = nullptr;
     pymol::cache_ptr<CGO> preOpt;
 
     {
@@ -394,6 +396,14 @@ static void ObjectCGOGenerateCGO(PyMOLGlobals * G, ObjectCGO * I, ObjectCGOState
               CGOFree(allButSpheres);
             }
           }
+          if (CGOHasBezierOperations(convertcgo)) {
+            CGO* allButBezier = new CGO(G);
+            allBeziers = CGOOptimizeBezier(convertcgo);
+            CGOFilterOutBezierOperationsInto(convertcgo, allButBezier);
+            CGOStop(allButBezier);
+            CGOFree(convertcgo);
+            convertcgo = allButBezier;
+          }
           preOpt.reset(CGOSimplify(convertcgo, 0));
         } else {
           preOpt.reset(CGOSimplifyNoCompress(convertcgo, 0));
@@ -434,6 +444,10 @@ static void ObjectCGOGenerateCGO(PyMOLGlobals * G, ObjectCGO * I, ObjectCGOState
         preOpt->free_append(allSpheres);
       }
 
+      if (allBeziers) {
+        preOpt->free_append(allBeziers);
+      }
+
       sobj->renderCGO = std::move(preOpt);
     } else {
       assert(sobj->hasTransparency == CGOHasTransparency(preOpt.get()));
@@ -449,6 +463,7 @@ static void ObjectCGOGenerateCGO(PyMOLGlobals * G, ObjectCGO * I, ObjectCGOState
 
     assert(allCylinders == nullptr);
     assert(allSpheres == nullptr);
+    assert(allBeziers == nullptr);
 
     sobj->renderWithShaders = use_shader;
     sobj->cgo_lighting = cgo_lighting;
@@ -463,14 +478,14 @@ void ObjectCGO::render(RenderInfo * info)
   int state = info->state;
   CRay *ray = info->ray;
   const RenderPass pass = info->pass;
-  ObjectCGOState *sobj = NULL;
-  const float *color = NULL;
+  ObjectCGOState *sobj = nullptr;
+  const float *color = nullptr;
   bool use_shader = false, cgo_lighting = false;
-  ObjectGadgetRamp *ramp = NULL;
+  ObjectGadgetRamp *ramp = nullptr;
   
   use_shader = SettingGetGlobal_b(G, cSetting_cgo_use_shader) &
     SettingGetGlobal_b(G, cSetting_use_shaders);
-  cgo_lighting = SettingGet_i(G, I->Setting.get(), NULL, cSetting_cgo_lighting);
+  cgo_lighting = SettingGet_i(G, I->Setting.get(), nullptr, cSetting_cgo_lighting);
 
   ObjectPrepareContext(I, info);
   ramp = ColorGetRamp(G, I->Color);
@@ -532,11 +547,11 @@ ObjectCGOState::ObjectCGOState(const ObjectCGOState& other)
 
 static CGO *ObjectCGOPyListFloatToCGO(PyMOLGlobals * G, PyObject * list)
 {
-  CGO *cgo = NULL;
+  CGO *cgo = nullptr;
   int len;
   int ok = true;
   int result;
-  float *raw = NULL;
+  float *raw = nullptr;
 
   if(PyList_Check(list)) {
     len = PConvPyListToFloatArray(list, &raw);
@@ -563,7 +578,7 @@ static CGO *ObjectCGOPyListFloatToCGO(PyMOLGlobals * G, PyObject * list)
 
 static CGO *ObjectCGOFloatArrayToCGO(PyMOLGlobals * G, float *raw, int len, int quiet)
 {
-  CGO *cgo = NULL;
+  CGO *cgo = nullptr;
   int ok = true;
   int result;
 
@@ -586,7 +601,7 @@ static CGO *ObjectCGOFloatArrayToCGO(PyMOLGlobals * G, float *raw, int len, int
 
 ObjectCGO *ObjectCGOFromCGO(PyMOLGlobals * G, ObjectCGO * obj, CGO * cgo, int state)
 {
-  ObjectCGO *I = NULL;
+  ObjectCGO *I = nullptr;
 
   int size_n;
 
@@ -620,15 +635,15 @@ ObjectCGO *ObjectCGOFromCGO(PyMOLGlobals * G, ObjectCGO * obj, CGO * cgo, int st
 ObjectCGO *ObjectCGONewVFontTest(PyMOLGlobals * G, const char *text, float *pos)
 {
 
-  ObjectCGO *I = NULL;
+  ObjectCGO *I = nullptr;
   int font_id;
-  CGO *cgo = NULL;
+  CGO *cgo = nullptr;
   float scale[2] = { 1.0, 1.0 };
 
   font_id = VFontLoad(G, 1, 1, 1, true);
   cgo = CGONew(G);
-  VFontWriteToCGO(G, font_id, cgo, text, pos, scale, NULL, NULL);
-  I = ObjectCGOFromCGO(G, NULL, cgo, 0);
+  VFontWriteToCGO(G, font_id, cgo, text, pos, scale, nullptr, nullptr);
+  I = ObjectCGOFromCGO(G, nullptr, cgo, 0);
 
   return (I);
 }
@@ -642,7 +657,7 @@ ObjectCGO *ObjectCGODefine(PyMOLGlobals * G, ObjectCGO * obj, PyObject * pycgo,
 {
   assert(PyGILState_Check());
 
-  ObjectCGO *I = NULL;
+  ObjectCGO *I = nullptr;
 
   CGO *cgo, *font_cgo;
   int est;
@@ -651,7 +666,7 @@ ObjectCGO *ObjectCGODefine(PyMOLGlobals * G, ObjectCGO * obj, PyObject * pycgo,
 
   if(obj) {
     if(obj->type != cObjectCGO){     /* TODO: handle this */
-      obj = NULL;
+      obj = nullptr;
   }
     size_n = obj->State.size();
   }
@@ -665,7 +680,7 @@ ObjectCGO *ObjectCGODefine(PyMOLGlobals * G, ObjectCGO * obj, PyObject * pycgo,
     state = I->State.size();
   }
   if(I->State.size() <= state) {
-    I->State.resize(size_n + 1, ObjectCGOState(G));
+    I->State.resize(state + 1, ObjectCGOState(G));
   }
 
   I->State[state].origCGO = nullptr;
@@ -678,7 +693,7 @@ ObjectCGO *ObjectCGODefine(PyMOLGlobals * G, ObjectCGO * obj, PyObject * pycgo,
           est = CGOCheckForText(cgo);
           if(est) {
             CGOPreloadFonts(cgo);
-            font_cgo = CGODrawText(cgo, est, NULL);
+            font_cgo = CGODrawText(cgo, est, nullptr);
             CGOFree(cgo);
             cgo = font_cgo;
           }
@@ -701,7 +716,7 @@ ObjectCGO *ObjectCGODefine(PyMOLGlobals * G, ObjectCGO * obj, PyObject * pycgo,
 ObjectCGO *ObjectCGOFromFloatArray(PyMOLGlobals * G, ObjectCGO * obj,
                                    float *array, int size, int state, int quiet)
 {
-  ObjectCGO *I = NULL;
+  ObjectCGO *I = nullptr;
 
   CGO *cgo, *font_cgo;
   int est;
@@ -710,7 +725,7 @@ ObjectCGO *ObjectCGOFromFloatArray(PyMOLGlobals * G, ObjectCGO * obj,
 
   if(obj) {
     if(obj->type != cObjectCGO){     /* TODO: handle this */
-      obj = NULL;
+      obj = nullptr;
   }
     size_n = obj->State.size();
   }
@@ -734,7 +749,7 @@ ObjectCGO *ObjectCGOFromFloatArray(PyMOLGlobals * G, ObjectCGO * obj,
     est = CGOCheckForText(cgo);
     if(est) {
       CGOPreloadFonts(cgo);
-      font_cgo = CGODrawText(cgo, est, NULL);
+      font_cgo = CGODrawText(cgo, est, nullptr);
       CGOFree(cgo);
       cgo = font_cgo;
     }
