@@ -20,7 +20,6 @@ Z* -------------------------------------------------------------------
 #include"os_std.h"
 
 #include"Base.h"
-#include"OOMac.h"
 #include"Vector.h"
 #include"MemoryDebug.h"
 #include"Err.h"
@@ -34,6 +33,7 @@ Z* -------------------------------------------------------------------
 #include"Feedback.h"
 #include"DistSet.h"
 #include"ListMacros.h"
+#include "Interactions.h"
 #ifdef _PYMOL_INCENTIVE
 #endif
 
@@ -44,7 +44,7 @@ int ObjectDistGetLabelTxfVertex(ObjectDist * I, int state, int index, float *v)
   int result = 0;
   if(!I->DSet.empty()) {
     if(state < 0)
-      state = SettingGet_i(I->G, NULL, I->Setting.get(), cSetting_state) - 1;
+      state = SettingGet_i(I->G, nullptr, I->Setting.get(), cSetting_state) - 1;
     if(state < 0)
       state = SceneGetState(I->G);
     if(I->DSet.size() == 1)
@@ -52,7 +52,7 @@ int ObjectDistGetLabelTxfVertex(ObjectDist * I, int state, int index, float *v)
     state = state % I->DSet.size();
     {
       DistSet *ds = I->DSet[state].get();
-      if((!ds) && (SettingGet_b(I->G, I->Setting.get(), NULL, cSetting_all_states))) {
+      if((!ds) && (SettingGet_b(I->G, I->Setting.get(), nullptr, cSetting_all_states))) {
         state = 0;
         ds = I->DSet[state].get();
       }
@@ -74,7 +74,7 @@ int ObjectDistMoveLabel(ObjectDist * I, int state, int index, float *v, int mode
     state = 0;
   state = state % I->DSet.size();
   if((!I->DSet[state])
-     && (SettingGet_b(I->G, I->Setting.get(), NULL, cSetting_all_states)))
+     && (SettingGet_b(I->G, I->Setting.get(), nullptr, cSetting_all_states)))
     state = 0;
   /* find the corresponding distance set, for this state */
   auto ds = I->DSet[state].get();
@@ -178,7 +178,7 @@ static int ObjectDistDSetFromPyList(ObjectDist * I, PyObject * list)
 /*========================================================================*/
 PyObject *ObjectDistAsPyList(ObjectDist * I)
 {
-  PyObject *result = NULL;
+  PyObject *result = nullptr;
 
   /* first, dump the atoms */
 
@@ -195,15 +195,15 @@ PyObject *ObjectDistAsPyList(ObjectDist * I)
 int ObjectDistNewFromPyList(PyMOLGlobals * G, PyObject * list, ObjectDist ** result)
 {
   int ok = true;
-  ObjectDist *I = NULL;
-  (*result) = NULL;
+  ObjectDist *I = nullptr;
+  (*result) = nullptr;
 
   if(ok)
     ok = PyList_Check(list);
 
   I = new ObjectDist(G);
   if(ok)
-    ok = (I != NULL);
+    ok = (I != nullptr);
 
   if(ok){
     auto *val = PyList_GetItem(list, 0);
@@ -299,7 +299,7 @@ static CSetting **ObjectDistGetSettingHandle(ObjectDist * I, int state)
   if(state < 0) {
     return (&I->Setting.get());
   } else {
-    return (NULL);
+    return (nullptr);
   }
 }
 #endif
@@ -450,6 +450,12 @@ ObjectDist *ObjectDistNewFromSele(PyMOLGlobals * G, ObjectDist * oldObj,
           ENDFB(G);
         I->DSet[a] = nullptr;
 #endif
+      } else if (mode == 9) { // 9: halogen-bond interaction
+        I->DSet[a].reset(pymol::FindHalogenBondInteractions(G,
+            I->DSet[a].release(), sele1, state1, sele2, state2, cutoff, &dist));
+      } else if (mode == 10) { // 10: salt-bridge interaction
+        I->DSet[a].reset(pymol::FindSaltBridgeInteractions(G,
+            I->DSet[a].release(), sele1, state1, sele2, state2, cutoff, &dist));
       } else {
         I->DSet[a].reset(SelectorGetDistSet(
             G, I->DSet[a].release(), sele1, state1, sele2, state2, mode, cutoff, &dist));
@@ -556,7 +562,7 @@ ObjectDist *ObjectDistNewFromAngleSele(PyMOLGlobals * G, ObjectDist * oldObj,
   }
   /* else {
      VLAFreeP(I->DSet);
-     OOFreeP(I);
+     DeleteP(I);
      }
    */
   ObjectDistUpdateExtents(I);
@@ -650,7 +656,7 @@ ObjectDist *ObjectDistNewFromDihedralSele(PyMOLGlobals * G, ObjectDist * oldObj,
   }
   /* else {
      VLAFreeP(I->DSet);
-     OOFreeP(I);
+     DeleteP(I);
      }
    */
   ObjectDistUpdateExtents(I);
