@@ -45,7 +45,7 @@ struct ObjectMeshState : public CObjectState {
   pymol::vla<float> AtomVertex;
   int CarveFlag = false;
   float CarveBuffer = 0.0f;
-  int MeshMode;
+  cIsomeshMode MeshMode;
   pymol::cache_ptr<CGO> UnitCellCGO;
   WordType caption{};
   float AltLevel;
@@ -56,29 +56,29 @@ struct ObjectMeshState : public CObjectState {
   ObjectMeshState(PyMOLGlobals* G);
 };
 
-struct ObjectMesh : public CObject {
-  pymol::vla<ObjectMeshState> State;
+struct ObjectMesh : public pymol::CObject {
+  std::vector<ObjectMeshState> State;
   int NState = 0;
   ObjectMesh(PyMOLGlobals* G);
 
   // virtual methods
   void update() override;
   void render(RenderInfo* info) override;
-  void invalidate(int rep, int level, int state) override;
+  void invalidate(cRep_t rep, cRepInv_t level, int state) override;
   int getNFrame() const override;
-  CObject* clone() const override;
+  pymol::CObject* clone() const override;
 };
 
 ObjectMesh *ObjectMeshFromBox(PyMOLGlobals * G, ObjectMesh * obj, ObjectMap * map,
                               int map_state,
                               int state, float *mn, float *mx,
-                              float level, int meshMode,
+                              float level, cIsomeshMode,
                               float carve, float *vert_vla, float alt_level, int quiet);
 ObjectMesh *ObjectMeshFromXtalSym(PyMOLGlobals * G, ObjectMesh * obj, ObjectMap * map,
                                   CSymmetry * sym,
                                   int map_state,
                                   int state, float *mn, float *mx,
-                                  float level, int meshMode,
+                                  float level, cIsomeshMode,
                                   float carve, float *vert_vla,
                                   float alt_level, int quiet);
 void ObjectMeshDump(ObjectMesh * I, const char *fname, int state, int quiet);
