@@ -246,14 +246,14 @@ static int RepMeshCGOGenerate(RepMesh * I, RenderInfo * info)
 
   if (use_shader) {
     if (ok){
-      CGO *convertcgo = NULL;
+      CGO *convertcgo = nullptr;
       ok &= CGOStop(I->shaderCGO);
       if (ok)
 	convertcgo = CGOCombineBeginEnd(I->shaderCGO, 0);    
       CHECKOK(ok, convertcgo);
       CGOFree(I->shaderCGO);    
       I->shaderCGO = convertcgo;
-      convertcgo = NULL;
+      convertcgo = nullptr;
       if (ok){
 	if (dot_as_spheres){
 	  CGO *tmpCGO = CGONew(G);
@@ -296,255 +296,264 @@ static int RepMeshCGOGenerate(RepMesh * I, RenderInfo * info)
 	convertcgo->use_shader = true;
 	CGOFree(I->shaderCGO);
 	I->shaderCGO = convertcgo;
-	convertcgo = NULL;
+	convertcgo = nullptr;
       }
     }
   }
   return ok;
 }
 
-void RepMesh::render(RenderInfo* info)
+static void RepMeshRenderRay(const RepMesh* I, CRay* ray, float line_width)
 {
-  auto I = this;
-  CRay *ray = info->ray;
-  auto pick = info->pick;
-  float *v = I->V.data();
-  float *vc = I->VC;
-  int *n = I->N.data();
-  int c;
-  const float *col = NULL;
-  float line_width = SceneGetDynamicLineWidth(info, I->Width);
-  bool const dot_as_spheres = I->mesh_type == cIsomeshMode::isodot &&
-                              SettingGet<bool>(*cs, cSetting_dot_as_spheres);
-  int ok = true;
-
-  if(ray) {
-    if(n) {
-      float radius;
-
-      if(I->Radius <= 0.0F) {
-        radius = ray->PixelRadius * line_width / 2.0F;
-      } else {
-        radius = I->Radius;
-      }
-      /* looks like were missing some code here --
-
-         what about mesh_type?
-
-       */
-
-      if(I->oneColorFlag)
-        col = ColorGet(G, I->oneColor);
-      ray->color3fv(ColorGet(G, I->obj->Color));
-      switch (I->mesh_type) {
-      case cIsomeshMode::isomesh:
-        while(ok && *n) {
-          c = *(n++);
-          if(c--) {
-            vc += 3;
-            v += 3;
-            if(I->oneColorFlag) {
-              while(ok && c--) {
-                ok &= ray->sausage3fv(v - 3, v, radius, col, col);
-                v += 3;
-                vc += 3;
-              }
-            } else {
-              while(ok && c--) {
-                ok &= ray->sausage3fv(v - 3, v, radius, vc - 3, vc);
-                v += 3;
-                vc += 3;
-              }
-            }
-          }
-        }
-      case cIsomeshMode::isodot:
-        while(ok && *n) {
-          c = *(n++);
-          if(I->oneColorFlag) {
-            ray->color3fv(col);
-            while(ok && c--) {
-              ok &= ray->sphere3fv(v, radius);
-              v += 3;
-              vc += 3;
-            }
-          } else {
-            while(ok && c--) {
-              ray->color3fv(vc);
-              ok &= ray->sphere3fv(v, radius);
-              v += 3;
-              vc += 3;
-            }
-          }
-        }
-        break;
-      }
-    }
-  } else if(G->HaveGUI && G->ValidContext) {
-    if(pick) {
-      /* no picking meshes */
-    } else {
-      short use_shader, generate_shader_cgo = 0;
-      use_shader = SettingGetGlobal_b(G, cSetting_mesh_use_shader) &
-                   SettingGetGlobal_b(G, cSetting_use_shaders);
-      bool const mesh_as_cylinders =
-          SettingGet<bool>(G, cSetting_render_as_cylinders) &&
-          SettingGet<bool>(G, cSetting_mesh_as_cylinders) &&
-          I->mesh_type != cIsomeshMode::isodot;
-
-      if (I->shaderCGO && !use_shader){
-	CGOFree(I->shaderCGO);
-	I->shaderCGO = 0;
-      }
-      if (I->shaderCGO && ((mesh_as_cylinders ^ I->shaderCGO->has_draw_cylinder_buffers) ||
-			   (dot_as_spheres ^ I->shaderCGO->has_draw_sphere_buffers))){
-	CGOFree(I->shaderCGO);
-	I->shaderCGO = 0;
-      }
-
-      if (use_shader){
-	if (!I->shaderCGO){
-	  I->shaderCGO = CGONew(G);
-	  CHECKOK(ok, I->shaderCGO);
-	  if (ok)
-	    I->shaderCGO->use_shader = true;
-	  generate_shader_cgo = 1;
-	} else if (ok) {
-	  CGORender(I->shaderCGO, NULL, NULL, NULL, info, I);
-	  return;
-	}
-      }
-
-      if (ok){
-	if (generate_shader_cgo){
-	  ok &= RepMeshCGOGenerate(I, info);
-	}
-      }
-
-      int lighting =
-        SettingGet_i(G, I->cs->Setting.get(), I->obj->Setting.get(), cSetting_mesh_lighting);
-      if(!lighting) {
-        if(!info->line_lighting){
-	  if (!use_shader && !generate_shader_cgo){
-	    glDisable(GL_LIGHTING);
-	  }
-	}
-      }
-      if (!generate_shader_cgo){
-	switch (I->mesh_type) {
-	case cIsomeshMode::isomesh:
-	  if(info->width_scale_flag)
-	    glLineWidth(line_width * info->width_scale);
-	  else
-	    glLineWidth(line_width);
-	  break;
-        case cIsomeshMode::isodot:
-	  if(info->width_scale_flag)
-	    glPointSize(SettingGet_f
-			(G, I->cs->Setting.get(), I->obj->Setting.get(),
-			 cSetting_dot_width) * info->width_scale);
-	  else
-	    glPointSize(SettingGet_f
-			(G, I->cs->Setting.get(), I->obj->Setting.get(), cSetting_dot_width));
-	  break;
-	}
-      }
-
-      if (ok){
-	if (!generate_shader_cgo){
-	  SceneResetNormal(G, false);
-	}
-      }
-
-      switch (I->mesh_type) {
-      case cIsomeshMode::isomesh:
-	if(n) {
-	  if (!generate_shader_cgo){
-	    if(I->oneColorFlag) {
-	      while(*n) {
-		glColor3fv(ColorGet(G, I->oneColor));
-		c = *(n++);
-		glBegin(GL_LINE_STRIP);
-		while(c--) {
-		  glVertex3fv(v);
-		  v += 3;
-		}
-		glEnd();
-	      }
-	    } else {
-	      while(*n) {
-		c = *(n++);
-		glBegin(GL_LINE_STRIP);
-		while(c--) {
-		  glColor3fv(vc);
-		  vc += 3;
-		  glVertex3fv(v);
-		  v += 3;
-		}
-		glEnd();
-	      }
-	    }
-	  }
-	}
-	break;
-      case cIsomeshMode::isodot:
-	glPointSize(SettingGet_f
-		    (G, I->cs->Setting.get(), I->obj->Setting.get(), cSetting_dot_width));
-	if(ok && n) {
-	  if (!generate_shader_cgo){
-	    if(I->oneColorFlag) {
-	      while(*n) {
-		glColor3fv(ColorGet(G, I->oneColor));
-		c = *(n++);
-		glBegin(GL_POINTS);
-		while(c--) {
-		  glVertex3fv(v);
-		  v += 3;
-		}
-		glEnd();
-	      }
-	    } else {
-	      while(*n) {
-		c = *(n++);
-		glBegin(GL_POINTS);
-		while(c--) {
-		  glColor3fv(vc);
-		  vc += 3;
-		  glVertex3fv(v);
-		  v += 3;
-		}
-		glEnd();
-	      }
-	    }
-	  }
-	}
-	break;
-      }
-      
-      /* end of rendering, if using shaders, then render CGO */
-      if (use_shader) {
-	if (ok){
-	  {
-	    const float *color;
-	    color = ColorGet(G, I->obj->Color);
-	    CGORender(I->shaderCGO, color, NULL, NULL, info, I);
-	  }
-	}
-      }
-      
-#ifndef PURE_OPENGL_ES_2
-      if(!use_shader && !lighting)
-        glEnable(GL_LIGHTING);
-#endif
-    }
+  auto* n = I->N.data();
+  if (!n) {
+    return;
   }
-  if (!ok){
+  bool ok = true;
+  float radius{};
+
+  if (I->Radius <= 0.0f) {
+    radius = ray->PixelRadius * line_width / 2.0f;
+  } else {
+    radius = I->Radius;
+  }
+  /* looks like were missing some code here --
+
+      what about mesh_type?
+
+    */
+
+  const float* col = nullptr;
+  auto G = I->G;
+  if (I->oneColorFlag) {
+    col = ColorGet(G, I->oneColor);
+  }
+  ray->color3fv(ColorGet(G, I->obj->Color));
+
+  auto* v = I->V.data();
+  auto* vc = I->VC;
+  switch (I->mesh_type) {
+  case cIsomeshMode::isomesh:
+    while (ok && *n) {
+      int c = *(n++);
+      if (c--) {
+        vc += 3;
+        v += 3;
+        if (I->oneColorFlag) {
+          while (ok && c--) {
+            ok &= ray->sausage3fv(v - 3, v, radius, col, col);
+            v += 3;
+            vc += 3;
+          }
+        } else {
+          while (ok && c--) {
+            ok &= ray->sausage3fv(v - 3, v, radius, vc - 3, vc);
+            v += 3;
+            vc += 3;
+          }
+        }
+      }
+    }
+  case cIsomeshMode::isodot:
+    while (ok && *n) {
+      int c = *(n++);
+      if (I->oneColorFlag) {
+        ray->color3fv(col);
+        while (ok && c--) {
+          ok &= ray->sphere3fv(v, radius);
+          v += 3;
+          vc += 3;
+        }
+      } else {
+        while (ok && c--) {
+          ray->color3fv(vc);
+          ok &= ray->sphere3fv(v, radius);
+          v += 3;
+          vc += 3;
+        }
+      }
+    }
+    break;
+  }
+}
+
+static void RepMeshPick(const RepMesh* I)
+{
+  /* No-op; TODO? */
+}
+
+static void RepMeshRenderImmediate(
+    RepMesh* I, RenderInfo* info, float line_width)
+{
+  auto G = I->G;
+  float* v = I->V.data();
+  float* vc = I->VC;
+  int* n = I->N.data();
+  if (I->shaderCGO) {
+    CGOFree(I->shaderCGO);
+    I->shaderCGO = nullptr;
+  }
+#ifndef PURE_OPENGL_ES_2
+  int lighting = SettingGet_i(
+      G, I->cs->Setting.get(), I->obj->Setting.get(), cSetting_mesh_lighting);
+  if (!lighting && !info->line_lighting) {
+    glDisable(GL_LIGHTING);
+  }
+  switch (I->mesh_type) {
+  case cIsomeshMode::isomesh:
+    if (info->width_scale_flag)
+      glLineWidth(line_width * info->width_scale);
+    else
+      glLineWidth(line_width);
+    break;
+  case cIsomeshMode::isodot:
+    if (info->width_scale_flag)
+      glPointSize(SettingGet_f(G, I->cs->Setting.get(), I->obj->Setting.get(),
+                      cSetting_dot_width) *
+                  info->width_scale);
+    else
+      glPointSize(SettingGet_f(
+          G, I->cs->Setting.get(), I->obj->Setting.get(), cSetting_dot_width));
+    break;
+  }
+  SceneResetNormal(G, false);
+  switch (I->mesh_type) {
+  case cIsomeshMode::isomesh:
+    if (n) {
+      if (I->oneColorFlag) {
+        while (*n) {
+          glColor3fv(ColorGet(G, I->oneColor));
+          int c = *(n++);
+          glBegin(GL_LINE_STRIP);
+          while (c--) {
+            glVertex3fv(v);
+            v += 3;
+          }
+          glEnd();
+        }
+      } else {
+        while (*n) {
+          int c = *(n++);
+          glBegin(GL_LINE_STRIP);
+          while (c--) {
+            glColor3fv(vc);
+            vc += 3;
+            glVertex3fv(v);
+            v += 3;
+          }
+          glEnd();
+        }
+      }
+    }
+    break;
+  case cIsomeshMode::isodot:
+    glPointSize(SettingGet_f(
+        G, I->cs->Setting.get(), I->obj->Setting.get(), cSetting_dot_width));
+    if (n) {
+      if (I->oneColorFlag) {
+        while (*n) {
+          glColor3fv(ColorGet(G, I->oneColor));
+          int c = *(n++);
+          glBegin(GL_POINTS);
+          while (c--) {
+            glVertex3fv(v);
+            v += 3;
+          }
+          glEnd();
+        }
+      } else {
+        while (*n) {
+          int c = *(n++);
+          glBegin(GL_POINTS);
+          while (c--) {
+            glColor3fv(vc);
+            vc += 3;
+            glVertex3fv(v);
+            v += 3;
+          }
+          glEnd();
+        }
+      }
+    }
+    break;
+  }
+  if (!lighting) {
+    glEnable(GL_LIGHTING);
+  }
+#endif
+}
+
+void RepMeshRasterRender(RepMesh* I, RenderInfo* info)
+{
+  auto G = I->G;
+  bool ok = true;
+  bool generate_shader_cgo = false;
+  bool const mesh_as_cylinders =
+      SettingGet<bool>(G, cSetting_render_as_cylinders) &&
+      SettingGet<bool>(G, cSetting_mesh_as_cylinders) &&
+      I->mesh_type != cIsomeshMode::isodot;
+  bool const dot_as_spheres = I->mesh_type == cIsomeshMode::isodot &&
+                              SettingGet<bool>(*I->cs, cSetting_dot_as_spheres);
+
+  if (I->shaderCGO &&
+      ((mesh_as_cylinders ^ I->shaderCGO->has_draw_cylinder_buffers) ||
+          (dot_as_spheres ^ I->shaderCGO->has_draw_sphere_buffers))) {
+    CGOFree(I->shaderCGO);
+    I->shaderCGO = nullptr;
+  }
+  if (!I->shaderCGO) {
+    I->shaderCGO = CGONew(G);
+    CHECKOK(ok, I->shaderCGO);
+    if (ok) {
+      I->shaderCGO->use_shader = true;
+    }
+    generate_shader_cgo = true;
+  } else if (ok) {
+    CGORender(I->shaderCGO, nullptr, nullptr, nullptr, info, I);
+    return;
+  }
+
+  if (ok && generate_shader_cgo) {
+    ok &= RepMeshCGOGenerate(I, info);
+  }
+  if (ok) {
+    const auto* color = ColorGet(G, I->obj->Color);
+    CGORender(I->shaderCGO, color, nullptr, nullptr, info, I);
+  }
+  if (!ok) {
     CGOFree(I->shaderCGO);
     I->invalidate(cRepInvPurge);
     I->cs->Active[cRepMesh] = false;
   }
 }
 
+void RepMesh::render(RenderInfo* info)
+{
+  auto I = this;
+  CRay* ray = info->ray;
+  auto pick = info->pick;
+  float line_width = SceneGetDynamicLineWidth(info, I->Width);
+
+  if (ray) {
+    RepMeshRenderRay(I, ray, line_width);
+    return;
+  }
+  if (!(G->HaveGUI && G->ValidContext)) {
+    return;
+  }
+  if (pick) {
+    RepMeshPick(I);
+    return;
+  }
+  bool use_shader = SettingGet<bool>(G, cSetting_mesh_use_shader) & //
+                    SettingGet<bool>(G, cSetting_use_shaders);
+  if (use_shader) {
+    RepMeshRasterRender(I, info);
+    return;
+  }
+  RepMeshRenderImmediate(I, info, line_width);
+}
+
 bool RepMesh::sameVis() const
 {
   for (int idx = 0; idx < cs->NIndex; idx++) {
@@ -619,11 +628,11 @@ Rep* RepMesh::recolor()
       I->VC = pymol::malloc<float>(3 * I->NTot);
     vc = I->VC;
     /* now, assign colors to each point */
-    map = MapNew(G, I->max_vdw + probe_radius, cs->Coord, cs->NIndex, NULL);
+    map = MapNew(G, I->max_vdw + probe_radius, cs->Coord, cs->NIndex, nullptr);
     if(map) {
       MapSetupExpress(map);
       for(a = 0; a < I->NTot; a++) {
-        AtomInfoType *ai0 = NULL;
+        AtomInfoType *ai0 = nullptr;
         c1 = 1;
         minDist = FLT_MAX;
         i0 = -1;
@@ -707,7 +716,7 @@ Rep *RepMeshNew(CoordSet * cs, int state)
   ObjectMolecule *obj;
   CoordSet *ccs;
   int a, b, c, d, h, k, l, *n;
-  MapType *map = NULL, *smap = NULL;
+  MapType *map = nullptr, *smap = nullptr;
   /* grid */
   Vector3f minE, maxE, sizeE;
   float size;
@@ -763,7 +772,7 @@ Rep *RepMeshNew(CoordSet * cs, int state)
     }
   }
   if(!ok || !visFlag) {
-    return (NULL);              /* skip if no dots are visible */
+    return (nullptr);              /* skip if no dots are visible */
   }
 
   auto I = new RepMesh(cs, state);
@@ -772,14 +781,14 @@ Rep *RepMeshNew(CoordSet * cs, int state)
 
   min_spacing = SettingGet_f(G, cs->Setting.get(), obj->Setting.get(), cSetting_min_mesh_spacing);
 
-  I->N = NULL;
+  I->N = nullptr;
   I->NTot = 0;
-  I->V = NULL;
-  I->VC = NULL;
+  I->V = nullptr;
+  I->VC = nullptr;
   I->NDot = 0;
-  I->Dot = NULL;
-  I->LastVisib = NULL;
-  I->LastColor = NULL;
+  I->Dot = nullptr;
+  I->LastVisib = nullptr;
+  I->LastColor = nullptr;
   I->mesh_type = mesh_type;
   I->Radius = SettingGet_f(G, cs->Setting.get(), obj->Setting.get(), cSetting_mesh_radius);
   I->shaderCGO = 0;
@@ -790,24 +799,24 @@ Rep *RepMeshNew(CoordSet * cs, int state)
     float trim_cutoff =
       SettingGet_f(G, cs->Setting.get(), obj->Setting.get(), cSetting_mesh_cutoff);
     int trim_flag = false;
-    float *trim_vla = NULL;
-    MapType *trim_map = NULL;
+    float *trim_vla = nullptr;
+    MapType *trim_map = nullptr;
 
     int carve_state = 0;
     int carve_flag = false;
     float carve_cutoff =
       SettingGet_f(G, cs->Setting.get(), obj->Setting.get(), cSetting_mesh_carve_cutoff);
-    const char *carve_selection = NULL;
-    float *carve_vla = NULL;
-    MapType *carve_map = NULL;
+    const char *carve_selection = nullptr;
+    float *carve_vla = nullptr;
+    MapType *carve_map = nullptr;
 
     int clear_state = 0;
     int clear_flag = false;
     float clear_cutoff =
       SettingGet_f(G, cs->Setting.get(), obj->Setting.get(), cSetting_mesh_clear_cutoff);
-    const char *clear_selection = NULL;
-    float *clear_vla = NULL;
-    MapType *clear_map = NULL;
+    const char *clear_selection = nullptr;
+    float *clear_vla = nullptr;
+    MapType *clear_map = nullptr;
 
     int mesh_max = SettingGet_i(G, cs->Setting.get(), obj->Setting.get(), cSetting_mesh_grid_max);
     if(mesh_max < 1)
@@ -840,7 +849,7 @@ Rep *RepMeshNew(CoordSet * cs, int state)
         }
       }
       if(ok && nc) {
-        trim_map = MapNew(G, trim_cutoff, trim_vla, nc, NULL);
+        trim_map = MapNew(G, trim_cutoff, trim_vla, nc, nullptr);
 	CHECKOK(ok, trim_map);
         if(ok) {
           ok &= MapSetupExpress(trim_map);
@@ -951,8 +960,8 @@ Rep *RepMeshNew(CoordSet * cs, int state)
     if(ok && !solv_acc)
       ok &= RepMeshGetSolventDots(I, cs, minE, maxE, probe_radius);
     if(ok) {
-      smap = MapNew(G, probe_radius, I->Dot, I->NDot, NULL);
-      map = MapNew(G, I->max_vdw + probe_radius, cs->Coord, cs->NIndex, NULL);
+      smap = MapNew(G, probe_radius, I->Dot, I->NDot, nullptr);
+      map = MapNew(G, I->max_vdw + probe_radius, cs->Coord, cs->NIndex, nullptr);
     }
     if(ok && map && smap) {
       ok &= MapSetupExpress(smap);
@@ -1048,7 +1057,7 @@ Rep *RepMeshNew(CoordSet * cs, int state)
     FreeP(I->Dot);
     OrthoBusyFast(G, 2, 3);
     if(ok) {
-      ok &= IsosurfVolume(G, NULL, NULL, field, 1.0, I->N, I->V, NULL, mesh_type, mesh_skip,
+      ok &= IsosurfVolume(G, nullptr, nullptr, field, 1.0, I->N, I->V, nullptr, mesh_type, mesh_skip,
                     1.0F);
     }
     DeleteP(field);
@@ -1063,7 +1072,7 @@ Rep *RepMeshNew(CoordSet * cs, int state)
 	CHECKOK(ok, new_n);
         while(ok && (c = *(n++))) {
           int new_c = 0;
-          float *last_v = NULL;
+          float *last_v = nullptr;
           while(c--) {
             int a_keeper = false;
             if(trim_map) {
@@ -1127,14 +1136,14 @@ Rep *RepMeshNew(CoordSet * cs, int state)
                   *(new_v++) = *(v++);
                   *(new_v++) = *(v++);
                   *(new_v++) = *(v++);
-                  last_v = NULL;
+                  last_v = nullptr;
                 } else {
                   last_v = v;
                   v += 3;
                 }
               }
             } else {
-              last_v = NULL;
+              last_v = nullptr;
               v += 3;
               if(new_c) {
                 VLACheck(new_n, int, new_size + 1);     /* extends the zero count sentinel */
@@ -1176,7 +1185,7 @@ Rep *RepMeshNew(CoordSet * cs, int state)
   OrthoBusyFast(G, 4, 4);
   if(!ok) {
     delete I;
-    I = NULL;
+    I = nullptr;
   }
   return (Rep *) I;
 }
@@ -1218,7 +1227,7 @@ int RepMeshGetSolventDots(RepMesh * I, CoordSet * cs, float *min, float *max,
   probe_radius_plus = probe_radius * 1.5F;
 
   I->NDot = 0;
-  map = MapNew(G, I->max_vdw + probe_radius, cs->Coord, cs->NIndex, NULL);
+  map = MapNew(G, I->max_vdw + probe_radius, cs->Coord, cs->NIndex, nullptr);
   if(map) {
     MapSetupExpress(map);
     maxCnt = 0;
@@ -1297,7 +1306,7 @@ int RepMeshGetSolventDots(RepMesh * I, CoordSet * cs, float *min, float *max,
     }
     dot_flag[maxDot] = 1;       /* this guarantees that we have a valid dot */
 
-    map = MapNew(G, probe_radius_plus, I->Dot, I->NDot, NULL);
+    map = MapNew(G, probe_radius_plus, I->Dot, I->NDot, nullptr);
     if(map) {
       MapSetupExpress(map);
 
