@@ -21,7 +21,7 @@ Z* -------------------------------------------------------------------
 #include"os_gl.h"
 
 #include"Base.h"
-#include"OOMac.h"
+#include"Err.h"
 #include"RepRibbon.h"
 #include"Color.h"
 #include"Setting.h"
@@ -32,6 +32,7 @@ Z* -------------------------------------------------------------------
 #include"ShaderMgr.h"
 #include"CGO.h"
 #include "Lex.h"
+#include "CoordSet.h"
 
 struct RepRibbon : Rep {
   using Rep::Rep;
@@ -56,85 +57,128 @@ RepRibbon::~RepRibbon()
   CGOFree(shaderCGO);
 }
 
+static void RepRibbonRenderRay(RepRibbon* I, RenderInfo* info) {
+  auto ray = info->ray;
+  CGORenderRay(I->primitiveCGO, ray, info, nullptr, nullptr, I->cs->Setting.get(), I->obj->Setting.get());
+}
+
+static bool RepRibbonCGOGenerate(RepRibbon* I) {
+  bool ok = true;
+  CGO* convertcgo = nullptr;
+  auto G = I->G;
+  I->shaderCGO = CGONew(G);
+  CHECKOK(ok, I->shaderCGO);
+
+  bool ribbon_as_cylinders = SettingGet<bool>(G, cSetting_render_as_cylinders) &&
+                             SettingGet<bool>(G, I->cs->Setting.get(),
+                                                 I->obj->Setting.get(),
+                                                 cSetting_ribbon_as_cylinders);
+
+  if (ok)
+    I->shaderCGO->use_shader = true;
+
+  if (ok)
+    ok &= CGOResetNormal(I->shaderCGO, true);
+  if (ribbon_as_cylinders) {
+    if (ok)
+      ok &= CGOEnable(I->shaderCGO, GL_CYLINDER_SHADER);
+    if (ok)
+      ok &= CGOSpecial(I->shaderCGO, CYLINDER_WIDTH_FOR_RIBBONS);
+    convertcgo = CGOConvertLinesToCylinderShader(I->primitiveCGO, I->shaderCGO);
+    if (ok)
+      ok &= CGOAppendNoStop(I->shaderCGO, convertcgo);
+    if (ok)
+      ok &= CGODisable(I->shaderCGO, GL_CYLINDER_SHADER);
+    if (ok)
+      ok &= CGOStop(I->shaderCGO);
+  } else {
+    int trilines = SettingGetGlobal_b(G, cSetting_trilines);
+    int shader = trilines ? GL_TRILINES_SHADER : GL_LINE_SHADER;
+    if (ok)
+      ok &= CGOEnable(I->shaderCGO, shader);
+    if (ok)
+      ok &= CGODisable(I->shaderCGO, CGO_GL_LIGHTING);
+    if (trilines) {
+      if (ok)
+        ok &= CGOSpecial(I->shaderCGO, LINEWIDTH_DYNAMIC_WITH_SCALE_RIBBON);
+      convertcgo = CGOConvertToTrilinesShader(I->primitiveCGO, I->shaderCGO);
+    } else {
+      convertcgo = CGOConvertToLinesShader(I->primitiveCGO, I->shaderCGO);
+    }
+    if (ok)
+      ok &= CGOAppendNoStop(I->shaderCGO, convertcgo);
+    if (ok)
+      ok &= CGODisable(I->shaderCGO, shader);
+    if (ok)
+      ok &= CGOStop(I->shaderCGO);
+  }
+  I->shaderCGO_has_cylinders = ribbon_as_cylinders;
+  CGOFreeWithoutVBOs(convertcgo);
+  I->shaderCGO->use_shader = true;
+  return ok;
+}
+
+static void RepRibbonRenderRaster(RepRibbon* I, RenderInfo* info)
+{
+  auto G = I->G;
+  bool ribbon_as_cylinders = SettingGet<bool>(G, cSetting_render_as_cylinders) &&
+                             SettingGet<bool>(G, I->cs->Setting.get(),
+                                                 I->obj->Setting.get(),
+                                                 cSetting_ribbon_as_cylinders);
+  if (I->shaderCGO && (ribbon_as_cylinders ^ I->shaderCGO_has_cylinders)) {
+    CGOFree(I->shaderCGO);
+    I->shaderCGO = nullptr;
+  }
+  if (!I->shaderCGO) {
+    RepRibbonCGOGenerate(I);
+  }
+  CGORender(I->shaderCGO, nullptr, I->cs->Setting.get(), I->obj->Setting.get(),
+      info, I);
+}
+
+static void RepRibbonPick(RepRibbon* I, RenderInfo* info)
+{
+  CGORenderPicking(I->shaderCGO ? I->shaderCGO : I->primitiveCGO, info,
+      &I->context, I->cs->Setting.get(), I->obj->Setting.get(), I);
+}
+
+static void RepRibbonRenderImmediate(RepRibbon* I, RenderInfo* info)
+{
+  CGORender(I->primitiveCGO, nullptr, I->cs->Setting.get(),
+    I->obj->Setting.get(), info, I);
+}
+
 void RepRibbon::render(RenderInfo* info)
 {
   auto I = this;
   CRay *ray = info->ray;
   auto pick = info->pick;
-  int ok = true;
-  short use_shader = SettingGetGlobal_b(G, cSetting_ribbon_use_shader) &&
-                     SettingGetGlobal_b(G, cSetting_use_shaders);
-  bool ribbon_as_cylinders = SettingGetGlobal_b(G, cSetting_render_as_cylinders) &&
-                             SettingGet<bool>(G, I->cs->Setting.get(),
-                                                 I->obj->Setting.get(),
-                                                 cSetting_ribbon_as_cylinders);
 
-  if(ray) {
-#ifndef _PYMOL_NO_RAY
-    CGORenderRay(I->primitiveCGO, ray, info, NULL, NULL, I->cs->Setting.get(), I->obj->Setting.get());
-#endif
-  } else if(G->HaveGUI && G->ValidContext) {
-    if(pick) {
-      CGORenderGLPicking(I->shaderCGO ? I->shaderCGO : I->primitiveCGO, info, &I->context, I->cs->Setting.get(), I->obj->Setting.get(), I);
-    } else {
-      if (!use_shader && I->shaderCGO){
-	CGOFree(I->shaderCGO);
-	I->shaderCGO = 0;
-      }
-      if (I->shaderCGO && (ribbon_as_cylinders ^ I->shaderCGO_has_cylinders)){
-	CGOFree(I->shaderCGO);
-	I->shaderCGO = 0;
-      }
-
-      if (use_shader){
-	if (!I->shaderCGO){
-          CGO *convertcgo = NULL;
-	  I->shaderCGO = CGONew(G);
-	  CHECKOK(ok, I->shaderCGO);
-	  if (ok)
-	    I->shaderCGO->use_shader = true;
-
-          if (ok)
-            ok &= CGOResetNormal(I->shaderCGO, true);
-          if (ribbon_as_cylinders){
-            if (ok) ok &= CGOEnable(I->shaderCGO, GL_CYLINDER_SHADER);
-            if (ok) ok &= CGOSpecial(I->shaderCGO, CYLINDER_WIDTH_FOR_RIBBONS);
-            convertcgo = CGOConvertLinesToCylinderShader(I->primitiveCGO, I->shaderCGO);
-            if (ok) ok &= CGOAppendNoStop(I->shaderCGO, convertcgo);
-            if (ok) ok &= CGODisable(I->shaderCGO, GL_CYLINDER_SHADER);
-            if (ok) ok &= CGOStop(I->shaderCGO);
-          } else {
-            int trilines = SettingGetGlobal_b(G, cSetting_trilines);
-            int shader = trilines ? GL_TRILINES_SHADER : GL_LINE_SHADER;
-            if (ok) ok &= CGOEnable(I->shaderCGO, shader);
-            if (ok) ok &= CGODisable(I->shaderCGO, CGO_GL_LIGHTING);
-            if (trilines) {
-              if (ok) ok &= CGOSpecial(I->shaderCGO, LINEWIDTH_DYNAMIC_WITH_SCALE_RIBBON);
-              convertcgo = CGOConvertToTrilinesShader(I->primitiveCGO, I->shaderCGO);
-            } else {
-              convertcgo = CGOConvertToLinesShader(I->primitiveCGO, I->shaderCGO);
-            }
-            if (ok) ok &= CGOAppendNoStop(I->shaderCGO, convertcgo);
-            if (ok) ok &= CGODisable(I->shaderCGO, shader);
-            if (ok) ok &= CGOStop(I->shaderCGO);
-          }
-          I->shaderCGO_has_cylinders = ribbon_as_cylinders;
-          CGOFreeWithoutVBOs(convertcgo);
-          I->shaderCGO->use_shader = true;
-        }
-        CGORenderGL(I->shaderCGO, NULL, I->cs->Setting.get(), I->obj->Setting.get(), info, I);
-        return;
-      } else {
-        CGORenderGL(I->primitiveCGO, NULL, I->cs->Setting.get(), I->obj->Setting.get(), info, I);
-        return;
-      }
-    }
+  if (ray) {
+    RepRibbonRenderRay(I, info);
+    return;
   }
-  if (!ok){
+  if (!(G->HaveGUI && G->ValidContext)) {
+    return;
+  }
+  if (pick) {
+    RepRibbonPick(I, info);
+    return;
+  }
+
+  bool use_shader = SettingGet<bool>(G, cSetting_ribbon_use_shader) &&
+                    SettingGet<bool>(G, cSetting_use_shaders);
+
+  if (!use_shader && I->shaderCGO) {
     CGOFree(I->shaderCGO);
-    I->invalidate(cRepInvPurge);
-    I->cs->Active[cRepRibbon] = false;
+    I->shaderCGO = nullptr;
   }
+
+  if (use_shader) {
+    RepRibbonRenderRaster(I, info);
+    return;
+  }
+  RepRibbonRenderImmediate(I, info);
 }
 
 Rep *RepRibbonNew(CoordSet * cs, int state)
@@ -143,14 +187,14 @@ Rep *RepRibbonNew(CoordSet * cs, int state)
   ObjectMolecule *obj;
   int a, b, a1, a2, *i, *s, *at, *seg, nAt, *atp;
   float *v, *v1, *v2, *v3;
-  float *pv = NULL;
-  float *dv = NULL;
-  float *nv = NULL;
-  float *tv = NULL;
+  float *pv = nullptr;
+  float *dv = nullptr;
+  float *nv = nullptr;
+  float *tv = nullptr;
 
   float f0, f1, f2, f3, f4;
   float *d;
-  float *dl = NULL;
+  float *dl = nullptr;
   int nSeg;
   int sampling;
   float power_a = 5;
@@ -160,13 +204,13 @@ Rep *RepRibbonNew(CoordSet * cs, int state)
   int trace, trace_mode;
   int ribbon_color;
   int na_mode;
-  AtomInfoType *ai, *last_ai = NULL;
-  AtomInfoType *trailing_O3p_ai = NULL, *leading_O5p_ai = NULL;
+  AtomInfoType *ai, *last_ai = nullptr;
+  AtomInfoType *trailing_O3p_ai = nullptr, *leading_O5p_ai = nullptr;
   int trailing_O3p_a = 0, leading_O5p_a = 0, leading_O5p_a1 = 0;
 
   // skip if not visible
   if(!cs->hasRep(cRepRibbonBit))
-    return NULL;
+    return nullptr;
 
   auto I = new RepRibbon(cs, state);
 
@@ -268,7 +312,7 @@ Rep *RepRibbonNew(CoordSet * cs, int state)
             }
           }
 
-          trailing_O3p_ai = NULL;
+          trailing_O3p_ai = nullptr;
 
           if(leading_O5p_ai && (a2 < 0) && ((na_mode == 3) || (na_mode == 4))) {
             if((!AtomInfoSameResidueP(G, ai, leading_O5p_ai)) &&
@@ -284,7 +328,7 @@ Rep *RepRibbonNew(CoordSet * cs, int state)
               a2 = leading_O5p_a1;
             }
           }
-          leading_O5p_ai = NULL;
+          leading_O5p_ai = nullptr;
           last_ai = ai;
           if(a2 < 0)
             nSeg++;
@@ -420,7 +464,7 @@ Rep *RepRibbonNew(CoordSet * cs, int state)
     I->primitiveCGO = CGONew(G);
     CGOSpecialWithArg(I->primitiveCGO, LINE_LIGHTING, 0.f);
 
-    float alpha = 1.f - SettingGet_f(G, NULL, I->obj->Setting.get(), cSetting_ribbon_transparency);
+    float alpha = 1.f - SettingGet_f(G, nullptr, I->obj->Setting.get(), cSetting_ribbon_transparency);
     if(fabs(alpha-1.0) < R_SMALL4)
       alpha = 1.0F;
     CGOAlpha(I->primitiveCGO, alpha);  // would be good to set these at render time instead
@@ -537,7 +581,7 @@ Rep *RepRibbonNew(CoordSet * cs, int state)
     FreeP(nv);
   } else {
     delete I;
-    I = NULL;
+    I = nullptr;
   }
 
   FreeP(at);
@@ -560,7 +604,7 @@ void RepRibbonRenderImmediate(CoordSet * cs, RenderInfo * info)
     int active = false;
     int nAtIndex = obj->NAtom;
     const AtomInfoType *obj_AtomInfo = obj->AtomInfo.data();
-    const AtomInfoType *ai, *last_ai = NULL;
+    const AtomInfoType *ai, *last_ai = nullptr;
     int trace, trace_ostate =
       SettingGet_i(G, cs->Setting.get(), obj->Setting.get(), cSetting_ribbon_trace_atoms);
     int trace_mode =
