@@ -18,6 +18,8 @@ Z* -------------------------------------------------------------------
 #define _H_Executive
 
 #include <string>
+#include <unordered_set>
+
 #include "pymol/zstring_view.h"
 #include"os_python.h"
 
@@ -31,13 +33,13 @@ Z* -------------------------------------------------------------------
 #include"Ortho.h"
 #include"Word.h"
 #include "PyMOL.h"
-#include "Executive_pre.h"
 #include "Scene.h"
 #include "Result.h"
 #include "vla.h"
 #include "TrackerList.h"
 #include "Selector.h"
 #include "SpecRecSpecial.h"
+#include "MViewAction.h"
 
 enum cLoadType_t : int {
   cLoadTypeUnknown = -1,
@@ -127,6 +129,8 @@ enum cLoadType_t : int {
 
   cLoadTypeCCP4UnspecifiedStr = 76,
   cLoadTypeMRCStr = 77,
+  cLoadTypeBCIF = 78,
+  cLoadTypeBCIFStr = 79,
 };
 
 /* NOTE: if you add new content/object type above, then be sure to add
@@ -182,6 +186,7 @@ int ExecutiveCheckGroupMembership(
 #define cExecutiveGroupEmpty 8
 #define cExecutiveGroupPurge 9
 #define cExecutiveGroupExcise 10
+#define cExecutiveGroupRaise 11
 
 enum ExecRec_t
 {
@@ -219,7 +224,7 @@ pymol::Result<> ExecutiveLoad(
                   const char *object_name,
                   int state, int zoom,
                   int discrete, int finish, int multiplex, int quiet, const char *plugin,
-                  const char * object_props=NULL, const char * atom_props=NULL,
+                  const char * object_props=nullptr, const char * atom_props=nullptr,
                   bool mimic=true);
 
 int ExecutiveDebug(PyMOLGlobals * G, const char *name);
@@ -325,7 +330,7 @@ pymol::CObject* ExecutiveFindObjectByName(
 /**
  * Typed version of `ExecutiveFindObjectByName`
  * @param name Object name
- * @return NULL if object can't be found or has the wrong type
+ * @return nullptr if object can't be found or has the wrong type
  */
 template <typename T> T* ExecutiveFindObject(PyMOLGlobals* G, pymol::zstring_view name)
 {
@@ -339,6 +344,16 @@ pymol::CObject** ExecutiveFindObjectsByType(PyMOLGlobals * G, int objType);
 int ExecutiveIterateObject(PyMOLGlobals * G, pymol::CObject ** obj, void **hidden);
 pymol::Result<std::vector<DiscardedRec>> ExecutiveDelete(PyMOLGlobals * G, pymol::zstring_view nameView, bool save = false);
 
+/**
+ * @brief Deletes states from an object
+ * @param name name of the object
+ * @param states list of states to be deleted (0-based, must be sorted and
+ * unique)
+ * @note Currently only works on non-discrete molecular objects
+ */
+pymol::Result<> ExecutiveDeleteStates(
+    PyMOLGlobals* G, std::string_view name, const std::vector<int>& states);
+
 /**
  * @brief Unregisters the specification record from PyMOL
  * @param rec specification record to be purged/removed
@@ -403,7 +418,14 @@ int ExecutiveIndex(PyMOLGlobals * G, const char *s1, int mode, int **indexVLA,
 pymol::Result<> ExecutiveReset(PyMOLGlobals*, pymol::zstring_view);
 pymol::Result<> ExecutiveResetMatrix(
     PyMOLGlobals* G, const char* name, int mode, int state, int log, int quiet);
-void ExecutiveDrawNow(PyMOLGlobals * G);
+
+struct ExecutiveDrawInfo
+{
+  bool offscreen{};
+  bool clearTarget = true;
+};
+
+void ExecutiveDrawNow(PyMOLGlobals * G, ExecutiveDrawInfo execDrawInfo = {});
 int ExecutiveDrawCmd(PyMOLGlobals * G, int width, int height, int antialias,
                      int entire_window, int quiet);
 pymol::Result<int> ExecutiveCartoon(PyMOLGlobals* G, int type, const char* s1);
@@ -496,9 +518,24 @@ pymol::Result<float> ExecutiveGetArea(
     PyMOLGlobals*, const char* sele, int state, bool load_b);
 
 void ExecutiveInvalidateSceneMembers(PyMOLGlobals * G);
-void ExecutiveInvalidateSelectionIndicators(PyMOLGlobals *G);
-void ExecutiveInvalidateSelectionIndicatorsCGO(PyMOLGlobals *G);
-void ExecutiveRenderSelections(PyMOLGlobals * G, int curState, int slot, GridInfo *grid);
+
+/**
+ * Invalidates the selection indicators and resets selection texture size
+ */
+void ExecutiveInvalidateSelectionIndicators(PyMOLGlobals* G);
+
+/**
+ * Invalidates the selection indicators CGO
+ */
+void ExecutiveInvalidateSelectionIndicatorsCGO(PyMOLGlobals* G);
+
+/**
+ * Renders the selection indicators
+ * @param curState current state
+ * @param slot slot to render
+ * @param grid grid info
+ */
+void ExecutiveRenderSelections(PyMOLGlobals* G, int curState, int slot, GridInfo* grid);
 void ExecutiveHideSelections(PyMOLGlobals * G);
 pymol::Result<> ExecutiveSetTitle(PyMOLGlobals * G, const char *name, int state, const char *text);
 const char *ExecutiveGetTitle(PyMOLGlobals * G, const char *name, int state);
@@ -649,8 +686,8 @@ const char *ExecutiveFindBestNameMatch(PyMOLGlobals * G, const char *name);
 int ExecutiveSetVisFromPyDict(PyMOLGlobals * G, PyObject * dict);
 PyObject *ExecutiveGetVisAsPyDict(PyMOLGlobals * G);
 CField   *ExecutiveGetVolumeField(PyMOLGlobals * G, const char * objName, int state);
-pymol::Result<> ExecutiveSetVolumeRamp(PyMOLGlobals * G, const char * objName, std::vector<float> ramp_list);
-PyObject *ExecutiveGetVolumeRamp(PyMOLGlobals * G, const char * objName);
+pymol::Result<> ExecutiveSetVolumeRamp(PyMOLGlobals* G, const char* objName, std::vector<float> ramp_list, int state);
+PyObject* ExecutiveGetVolumeRamp(PyMOLGlobals* G, const char* objName, int state);
 
 pymol::Result<std::vector<float>>
 ExecutiveGetHistogram(PyMOLGlobals * G, const char * objName, int n_points,
@@ -724,18 +761,19 @@ pymol::Result<> ExecutiveVolume(PyMOLGlobals * G, const char *volume_name, const
 
 int ExecutiveVolumeColor(PyMOLGlobals * G, const char * volume_name, float * colors, int ncolors );
 
-void ExecutiveMotionDraw(PyMOLGlobals * G, BlockRect *rect, int expected ORTHOCGOARG);
+void ExecutiveMotionDraw(PyMOLGlobals * G, BlockRect *rect, int expected , CGO *orthoCGO);
 
 void ExecutiveMotionReinterpolate(PyMOLGlobals * G);
 
-pymol::Result<> ExecutiveMotionViewModify(PyMOLGlobals* G, int action,
-    int index, int count, int target, const char* name, int freeze, int quiet);
+pymol::Result<> ExecutiveMotionViewModify(PyMOLGlobals* G,
+    ViewElemAction action, int index, int count, int target, const char* name,
+    int freeze, int quiet);
 
 void ExecutiveMotionMenuActivate(PyMOLGlobals * G, BlockRect *rect, int expected,int passive, 
                                  int x, int y, int same);
-int ExecutiveGroupMotionModify(PyMOLGlobals *G, pymol::CObject *group, int action, 
-                               int index, int count, int target, int freeze);
-int ExecutiveGroupMotion(PyMOLGlobals *G, pymol::CObject *group,int action, int first,
+int ExecutiveGroupMotionModify(PyMOLGlobals* G, pymol::CObject* group,
+    ViewElemAction action, int index, int count, int target, int freeze);
+int ExecutiveGroupMotion(PyMOLGlobals *G, pymol::CObject *group, MViewAction action, int first,
                          int last, float power, float bias,
                          int simple, float linear, int wrap,
                          int hand, int window, int cycles, int state, int quiet);
@@ -744,7 +782,7 @@ int ExecutiveGroupTranslateTTT(PyMOLGlobals *G, pymol::CObject *group, const flo
 void ExecutiveMotionClick(PyMOLGlobals * G, BlockRect *rect, int mode, int expected, int x, int y, int nearest);
 void ExecutiveMotionTrim(PyMOLGlobals * G);
 void ExecutiveMotionExtend(PyMOLGlobals * G, int freeze);
-int ExecutiveMotionView(PyMOLGlobals *G, int action, int first,
+int ExecutiveMotionView(PyMOLGlobals *G, MViewAction action, int first,
                         int last, float power, float bias,
                         int simple, float linear, const char *name, int wrap,
                         int hand, int window, int cycles,
@@ -790,9 +828,9 @@ pymol::TrackerAdapter<SpecRec> ExecutiveGetSpecRecsFromPattern(PyMOLGlobals* G,
 
 char *ExecutiveGetObjectNames(PyMOLGlobals * G, int mode, const char *name, int enabled_only, int *numstrs);
 
-CoordSet * ExecutiveGetCoordSet(PyMOLGlobals * G, const char * name, int state, ObjectMolecule ** omp=NULL);
+CoordSet * ExecutiveGetCoordSet(PyMOLGlobals * G, const char * name, int state, ObjectMolecule ** omp=nullptr);
 pymol::Result<> ExecutiveLoadCoordset(
-    PyMOLGlobals* G, pymol::zstring_view oname, PyObject* model, int frame);
+    PyMOLGlobals* G, pymol::zstring_view oname, PyObject* model, int frame, bool quiet);
 
 void ExecutiveUndo(PyMOLGlobals * G, int dir);
 int ExecutiveSaveUndo(PyMOLGlobals * G, const char *s1, int state);
@@ -862,4 +900,53 @@ void ExecutiveSpecSetVisibility(PyMOLGlobals * G, SpecRec * rec,
  * @param color new bg color
  */
 pymol::Result<> ExecutiveBackgroundColor(PyMOLGlobals* G, pymol::zstring_view color);
+
+/**
+ * Sets background color
+ * @param colorIdx new bg color idx
+ */
+pymol::Result<> ExecutiveBackgroundColor(PyMOLGlobals* G, int colorIdx);
+
+/**
+ * Directs an object's rotation toward facing the center of a target
+ * @param targetObjectName name of target object
+ * @param mobileObjectName name of object to be rotated
+ */
+pymol::Result<> ExecutiveLookAt(PyMOLGlobals* G,
+    pymol::zstring_view targetObjectName, pymol::zstring_view mobileObjectName);
+
+/**
+ * Moves an object along a curve
+ * @param mobileObject object to be moved
+ * @param curveObject curve object to move mobileObject on
+ * @param t relative distance along the curve
+ */
+pymol::Result<> ExecutiveMoveOnCurve(PyMOLGlobals* G,
+    pymol::zstring_view mobileObject, pymol::zstring_view curveObject, float t);
+
+/**
+ * Adds a new curve object
+ * @param curveName name of curve
+ * @param curveType type of curve
+ */
+pymol::Result<> ExecutiveCurveNew(PyMOLGlobals* G,
+    pymol::zstring_view curveName, pymol::zstring_view curveType);
+
+/**
+ * Updates an object's dependencies. Dependencies of objects include distance
+ * or map objects that are dependent on the object.
+ * @param obj object to update dependencies for
+ */
+pymol::Result<> ExecutiveUpdateObjectDeps(
+    PyMOLGlobals* G, const pymol::CObject& obj);
+
+/**
+ * Retrieves an object's dependencies. Dependencies of objects include distance
+ * or map objects that are dependent on the object.
+ * @param obj object to retrieve dependencies for
+ * @param depth depth of recursive dependencies to retrieve
+ */
+pymol::Result<std::unordered_set<const pymol::CObject*>> ExecutiveGetObjectDeps(
+    PyMOLGlobals* G, const pymol::CObject& obj, unsigned int depth = 0);
+
 #endif
