@@ -9,19 +9,30 @@
 
 #include "os_python.h"
 #include "Base.h"
-#include "PyMOLGlobals.h"
 #include "Result.h"
 #include "SceneView.h"
+#include "Image.h"
 
 #include <vector>
 #include <string>
 
+struct PyMOLGlobals;
+
 enum {
   cMovieSceneStackDefault = 0,
   cMovieSceneStackUndo = 1,
   cMovieSceneStack_SIZE
 };
 
+enum {
+  STORE_VIEW   = (1 << 0),
+  STORE_ACTIVE = (1 << 1),
+  STORE_COLOR  = (1 << 2),
+  STORE_REP    = (1 << 3),
+  STORE_FRAME  = (1 << 4),
+  STORE_THUMBNAIL = (1 << 5)
+};
+
 struct MovieSceneFuncArgs
 {
   std::string key;
@@ -32,11 +43,13 @@ struct MovieSceneFuncArgs
   bool store_active = true;
   bool store_rep = true;
   bool store_frame = true;
+  bool store_thumbnail = true;
   float animate = -1.0f;
   std::string new_key;
   bool hand = true;
   std::string sele = "all";
   std::size_t stack = cMovieSceneStackDefault;
+  bool quiet = false;
 };
 
 /**
@@ -62,6 +75,14 @@ public:
  */
 class MovieScene {
 public:
+
+  MovieScene() = default;
+  MovieScene(const MovieScene&) = default;
+  MovieScene& operator=(const MovieScene&) = default;
+  MovieScene(MovieScene&&) = default;
+  MovieScene& operator=(MovieScene&&) = default;
+  ~MovieScene() = default;
+
   /// bitmask, features stored in this scene
   int storemask;
 
@@ -74,6 +95,11 @@ public:
   /// camera view
   SceneViewType view;
 
+  /// A png buffer storing a thumbnail of the scene
+  pymol::Image thumbnail;
+  constexpr static int THUMBNAIL_WIDTH = 220;
+  constexpr static int THUMBNAIL_HEIGHT = 124;
+
   /// atom properties (color, rep, etc.)
   std::map<int, MovieSceneAtom> atomdata;
 
@@ -107,8 +133,10 @@ pymol::Result<> MovieSceneStore(PyMOLGlobals * G, const char * name,
     bool store_active,
     bool store_rep,
     bool store_frame,
+    bool store_thumbnail,
     const char * sele,
-    std::size_t stack);
+    std::size_t stack,
+    bool quiet);
 
 pymol::Result<> MovieSceneRename(PyMOLGlobals * G, const char * name, const char * new_name = nullptr);
 
@@ -121,6 +149,10 @@ pymol::Result<> MovieSceneRecall(PyMOLGlobals * G, const char * name, float anim
     const char * sele = "all",
     size_t stack = cMovieSceneStackDefault);
 
+pymol::Result<> MovieSceneRecallImpl(PyMOLGlobals* G, const MovieScene& scene,
+    float animate, bool recall_view, bool recall_color, bool recall_active,
+    bool recall_rep, bool recall_frame, const char* sele);
+
 pymol::Result<> MovieSceneRecallAllInstant(PyMOLGlobals * G, pymol::zstring_view name,
     std::size_t stack = cMovieSceneStackDefault);
 
@@ -129,12 +161,16 @@ pymol::Result<> MovieSceneDelete(PyMOLGlobals * G, const char * name,
 
 pymol::Result<> MovieSceneOrder(PyMOLGlobals * G, const char * names,
     bool sort = false,
-    const char * location = NULL /* "current" */);
+    const char * location = nullptr /* "current" */);
 pymol::Result<> MovieSceneOrder(PyMOLGlobals* G, std::vector<std::string> names,
     bool sort = false, const char* location = nullptr);
 
 const std::vector<std::string> & MovieSceneGetOrder(PyMOLGlobals * G);
-
+std::vector<unsigned char> MovieSceneGetThumbnail(
+    PyMOLGlobals* G, pymol::zstring_view name);
+std::string MovieSceneGetMessage(PyMOLGlobals* G, pymol::zstring_view name);
+pymol::Result<> MovieSceneSetMessage(
+    PyMOLGlobals* G, pymol::zstring_view name, pymol::zstring_view message);
 void MovieScenesInit(PyMOLGlobals * G);
 void MovieScenesFree(PyMOLGlobals * G);
 
