@@ -70,6 +70,9 @@ if True:
             format = 'cc1'
         elif ext in ('sd',):
             format = 'sdf'
+        elif ext in ('sdfgz',):
+            zipped = 'gz'
+            format = 'sdf'
         elif ext in ('rst7',):
             format = 'rst'
         elif ext in ('o', 'dsn6', 'omap',):
@@ -89,6 +92,11 @@ if True:
             format = 'pdbml'
         elif ext in ('mmcif',):
             format = 'cif'
+        elif ext in ('bcif',):
+            format = 'bcif'
+        elif ext in ('bcifgz',):
+            format = 'bcif'
+            zipped = 'gz'
         elif re.match(r'pdb\d+$', ext):
             format = 'pdb'
         elif re.match(r'xyz_\d+$', ext):
@@ -907,7 +915,8 @@ EXAMPLE
             multiplex=-2
         ftype = getattr(loadable, format, None)
         if ftype is None:
-            assert format not in ('cif', 'mmtf', 'pdb', 'dx')
+            assert format not in ('cif', 'pdb', 'dx')
+            assert format not in ('mmtf', ) or format in loadfunctions
 
             if not isinstance(content, bytes):
                 content = content.encode("utf-8")
@@ -1113,9 +1122,9 @@ PYMOL API
         return r
 
     fetchHosts = {
-        "pdb"  : "https://ftp.wwpdb.org/pub/pdb",
+        "pdb"  : "https://files.wwpdb.org/pub/pdb",
         "pdbe" : "https://ftp.ebi.ac.uk/pub/databases/pdb",
-        "pdbj" : "http://ftp.pdbj.org/pub/pdb",
+        "pdbj" : "https://files.pdbj.org/pub/pdb",
     }
 
     hostPaths = {
@@ -1131,7 +1140,10 @@ PYMOL API
         "cif"  : [
             "https://files.rcsb.org/download/{code}.{type}.gz",
             "/data/structures/divided/mmCIF/{mid}/{code}.cif.gz",
-            "https://ftp-versioned.wwpdb.org/pdb_versioned/views/latest/coordinates/mmcif/{mid}/pdb_{code:0>8}/pdb_{code:0>8}_xyz.cif.gz",
+            "https://files-versioned.wwpdb.org/pdb_versioned/views/latest/coordinates/mmcif/{mid}/pdb_{code:0>8}/pdb_{code:0>8}_xyz.cif.gz",
+        ],
+        "bcif"  : [
+            "https://models.rcsb.org/{code}.{type}.gz",
         ],
         "2fofc" : "https://www.ebi.ac.uk/pdbe/coordinates/files/{code}.ccp4",
         "fofc" : "https://www.ebi.ac.uk/pdbe/coordinates/files/{code}_diff.ccp4",
@@ -1181,6 +1193,8 @@ PYMOL API
             nameFmt = '{type}_{code}.sdf'
         elif type == 'cif':
             pass
+        elif type == 'bcif':
+            pass
         elif type == 'mmtf':
             pass
         elif type == 'cc':
@@ -1299,7 +1313,7 @@ PYMOL API
                     obj_name = 'emd_' + obj_code
 
             chain = None
-            if (len(obj_code) > 4 and type in ('pdb', 'cif', 'mmtf') and
+            if (len(obj_code) > 4 and type in ('pdb', 'cif', 'mmtf', 'bcif') and
                     # "Extended PDB accession codes" have 8 characters,
                     # try to distinguish by leading non-zero digit
                     '1' <= obj_code[0] <= '9'):
@@ -1343,8 +1357,8 @@ ARGUMENTS
 
     state = the state number into which the file should loaded.
 
-    type = str: cif, pdb, pdb1, 2fofc, fofc, emd, cid, sid {default: cif
-    (default was "pdb" up to 1.7.6)}
+    type = str: cif, bcif, pdb, pdb1, 2fofc, fofc, emd, cid, sid
+    {default: cif (default was "pdb" up to 1.7.6)}
 
     async_ = 0/1: download in the background and do not block the PyMOL
     command line {default: 0 -- changed in PyMOL 2.3}
@@ -1414,7 +1428,7 @@ SEE ALSO
     cmd.load_coords
         '''
         with _self.lockcm:
-            r = _cmd.load_coordset(_self._COb, object, coords, int(state)-1)
+            r = _cmd.load_coordset(_self._COb, object, coords, int(state)-1, quiet)
         return r
 
     def load_coords(coords, selection, state=1, quiet=1, *, _self=cmd):
