@@ -12,13 +12,12 @@
 #-*
 #Z* -------------------------------------------------------------------
 
-from __future__ import print_function
-
 import sys
 cmd = sys.modules["pymol.cmd"]
 import math
 import os
 import glob
+import shutil
 import threading
 import time
 from . import colorprinting
@@ -53,19 +52,13 @@ def pause(pause=15,cycles=1,_self=cmd):
     movie_string = " ".join(movie_list)
     _self.mset(movie_string)
 
-def load(*args,**kw):
-    _self = kw.get('_self',cmd)
-    nam = "mov"
-    if len(args)>1:
-        nam = args[1]
-    fils = glob.glob(args[0])
-    fils.sort()
-    if not len(fils):
+def load(pattern, nam = "mov", _self=cmd, **kw):
+    fils = glob.glob(pattern)
+    if not fils:
         print("Error: no matching files")
-    else:
-        for a in fils:
-            _self.load(*(a,nam), **kw)
-#         _self.load(a,nam)
+        return
+    for a in sorted(fils):
+        _self.load(a, nam, **kw)
 
 def rock(first=1,last=-1,angle=30,phase=0,loop=1,axis='y',_self=cmd):
     first=int(first)
@@ -724,14 +717,14 @@ def _encode(filename,first,last,preserve,
 
     if done and ok and (encoder == 'mpeg_encode'):
         try:
-            from freemol import mpeg_encode
+            from pymol import mpeg_encode
         except:
             ok = 0
-            print("produce-error: Unable to import module freemol.mpeg_encode.")
+            print("produce-error: Unable to import module pymol.mpeg_encode.")
         if ok:
             if not mpeg_encode.validate():
                 ok = 0
-                print("produce-error: Unable to validate freemol.mpeg_encode.")
+                print("produce-error: Unable to validate pymol.mpeg_encode.")
         if not ok:
             print("produce-error: Unable to create mpeg file.")
         else:
@@ -768,17 +761,28 @@ def _encode(filename,first,last,preserve,
         import subprocess
         os.chdir(tmp_path)
         try:
-            args = ['ffmpeg',
-                '-f', 'image2',
-                '-framerate', '{:.3f}'.format(fps),
-                '-i', prefix + '%04d' + img_ext,
-            ]
-            if not fn_rel.endswith('.gif'):
-                args += [
-                '-crf', '10' if quality > 90 else '15' if quality > 80 else '20',
-                '-pix_fmt', 'yuv420p', # needed for Mac support
+            if fn_rel.endswith('.gif'):
+                palette = os.path.join(tmp_path, 'palette.png')
+                filters = f"fps={fps}"
+                process = subprocess.Popen(['ffmpeg', '-v', 'warning', '-thread_queue_size', '512', '-i', prefix + '%04d' + img_ext, '-vf', filters+',palettegen', '-y', palette], stderr=subprocess.PIPE)
+                stderr = process.communicate()[1]
+                colorprinting.warning(stderr.strip().decode(errors='replace'))
+                process = subprocess.Popen(['ffmpeg', '-v', 'warning', '-thread_queue_size', '512','-i', prefix + '%04d' + img_ext, '-i', palette, '-lavfi', filters+' [x]; [x][1:v] paletteuse', '-y', fn_rel], stderr=subprocess.PIPE)
+            else:
+                args = ['ffmpeg',
+                    '-f', 'image2',
+                    '-framerate', '{:.3f}'.format(fps),
+                    '-i', prefix + '%04d' + img_ext,
                 ]
-            process = subprocess.Popen(args + [fn_rel], stderr=subprocess.PIPE)
+                if fn_rel.endswith('.webm'):
+                    args_crf = ['-crf', '{:.0f}'.format(65 - (quality / 2))]
+                    args += ['-c:v', 'libvpx-vp9', '-b:v', '0'] + args_crf
+                else:
+                    args += [
+                    '-crf', '10' if quality > 90 else '15' if quality > 80 else '20',
+                    '-pix_fmt', 'yuv420p', # needed for Mac support
+                    ]
+                process = subprocess.Popen(args + [fn_rel], stderr=subprocess.PIPE)
             stderr = process.communicate()[1]
             colorprinting.warning(stderr.strip().decode(errors='replace'))
             if process.returncode != 0:
@@ -805,10 +809,7 @@ def _encode(filename,first,last,preserve,
                     print(" produce: finished.")
     _self.unset("keep_alive")
     if preserve<1:
-        if os.path.isdir(tmp_path):
-            for fil in glob.glob(os.path.join(tmp_path,prefix+"*")):
-                os.unlink(fil)
-            os.rmdir(tmp_path)
+        shutil.rmtree(tmp_path)
 
 produce_mode_dict = {
     'normal'  : 0,
@@ -820,26 +821,25 @@ produce_mode_sc = cmd.Shortcut(produce_mode_dict.keys())
 
 
 def find_exe(exe):
-    '''Return full path to executable or None.
+    r'''Return full path to executable or None.
     Excludes C:\Windows\System32\convert.exe
     Tests .exe extension on Unix (e.g. for legacy "mpeg_encode.exe" name).
     '''
-    from distutils.spawn import find_executable
-
-    path = os.getenv('PATH', '')
+    from shutil import which
 
     if exe.startswith('convert') and sys.platform == 'win32':
         # filter out C:\Windows\System32
         path = os.pathsep.join(p
-                for p in path.split(os.pathsep)
+                for p in os.getenv('PATH', '').split(os.pathsep)
                 if r'\windows\system32' not in p.lower())
+        return which(exe, path=path)
 
-    e = find_executable(exe, path)
+    if exe == 'mpeg_encode':
+        legacy = which(exe + '.exe')
+        if legacy:
+            return legacy
 
-    if not e and sys.platform != 'win32':
-        e = find_executable(exe + '.exe', path)
-
-    return e
+    return which(exe)
 
 
 def produce(filename, mode='', first=0, last=0, preserve=0,
@@ -848,13 +848,14 @@ def produce(filename, mode='', first=0, last=0, preserve=0,
     '''
 DESCRIPTION
 
-    Export a movie to an MPEG file.
+    Export a movie to an MPEG, WEBM, or GIF file.
 
-    Requires FREEMOL.
+    Which video formats and codecs are available depends on the availability
+    and feature set of your ffmpeg and ImageMagick installations.
 
 ARGUMENTS
 
-    filename = str: filename of MPEG file to produce
+    filename = str: filename of movie file to produce
 
     mode = draw or ray: {default: check "ray_trace_frames" setting}
 
@@ -864,7 +865,18 @@ ARGUMENTS
 
     preserve = 0 or 1: don't delete temporary files {default: 0}
 
+    encoder = ffmpeg|convert|mpeg_encode: Tool used for video encoding
+
     quality = 0-100: encoding quality {default: 90 (movie_quality setting)}
+
+    width = int: Width in pixels {default: from viewport}
+
+    height = int: Height in pixels {default: from viewport}
+
+EXAMPLE
+
+    movie.produce video.mp4, height=1080
+    movie.produce video.webm, height=720
     '''
     from pymol import CmdException
 
@@ -914,11 +926,6 @@ ARGUMENTS
     # check encoder
     if encoder == 'mpeg_encode':
         img_ext = '.ppm'
-        try:
-            from freemol import mpeg_encode
-        except ImportError:
-            print(" Error: This PyMOL build is not set up with FREEMOL (freemol.mpeg_encode import failed)")
-            return _self.DEFAULT_ERROR
     elif encoder not in ('ffmpeg', 'convert'):
         raise CmdException('unknown encoder "%s"' % encoder)
     elif not has_exe(encoder):
@@ -928,7 +935,7 @@ ARGUMENTS
         _self.set('opaque_background', quiet=quiet)
 
     # MP4 needs dimensions divisible by 2
-    if splitext[1] in ('.mp4', '.mov'):
+    if splitext[1] in ('.mp4', '.mov', '.webm'):
         if width < 1 or height < 1:
             w, h = _self.get_viewport()
             if width > 0:
